static const uint8_t unicode_rangetab[][2]={
	{0x0000 & 0xFF, 0x0040 & 0xFF},
	{0x0041 & 0xFF, 0x005a & 0xFF},
	{0x005b & 0xFF, 0x0060 & 0xFF},
	{0x0061 & 0xFF, 0x007a & 0xFF},
	{0x007b & 0xFF, 0x00a9 & 0xFF},
	{0x00aa & 0xFF, 0x00aa & 0xFF},
	{0x00ab & 0xFF, 0x00b9 & 0xFF},
	{0x00ba & 0xFF, 0x00ba & 0xFF},
	{0x00bb & 0xFF, 0x00bf & 0xFF},
	{0x00c0 & 0xFF, 0x00d6 & 0xFF},
	{0x00d7 & 0xFF, 0x00d7 & 0xFF},
	{0x00d8 & 0xFF, 0x00f6 & 0xFF},
	{0x00f7 & 0xFF, 0x00f7 & 0xFF},
	{0x00f8 & 0xFF, 0x00ff & 0xFF},
	{0x0100 & 0xFF, 0x01ff & 0xFF},
	{0x0200 & 0xFF, 0x02b8 & 0xFF},
	{0x02b9 & 0xFF, 0x02df & 0xFF},
	{0x02e0 & 0xFF, 0x02e4 & 0xFF},
	{0x02e5 & 0xFF, 0x02e9 & 0xFF},
	{0x02ea & 0xFF, 0x02eb & 0xFF},
	{0x02ec & 0xFF, 0x02ff & 0xFF},
	{0x0300 & 0xFF, 0x036f & 0xFF},
	{0x0370 & 0xFF, 0x0373 & 0xFF},
	{0x0374 & 0xFF, 0x0374 & 0xFF},
	{0x0375 & 0xFF, 0x0377 & 0xFF},
	{0x037a & 0xFF, 0x037d & 0xFF},
	{0x037e & 0xFF, 0x037e & 0xFF},
	{0x037f & 0xFF, 0x037f & 0xFF},
	{0x0384 & 0xFF, 0x0384 & 0xFF},
	{0x0385 & 0xFF, 0x0385 & 0xFF},
	{0x0386 & 0xFF, 0x0386 & 0xFF},
	{0x0387 & 0xFF, 0x0387 & 0xFF},
	{0x0388 & 0xFF, 0x038a & 0xFF},
	{0x038c & 0xFF, 0x038c & 0xFF},
	{0x038e & 0xFF, 0x03a1 & 0xFF},
	{0x03a3 & 0xFF, 0x03e1 & 0xFF},
	{0x03e2 & 0xFF, 0x03ef & 0xFF},
	{0x03f0 & 0xFF, 0x03ff & 0xFF},
	{0x0400 & 0xFF, 0x0484 & 0xFF},
	{0x0485 & 0xFF, 0x0486 & 0xFF},
	{0x0487 & 0xFF, 0x04ff & 0xFF},
	{0x0500 & 0xFF, 0x052f & 0xFF},
	{0x0531 & 0xFF, 0x0556 & 0xFF},
	{0x0559 & 0xFF, 0x058a & 0xFF},
	{0x058d & 0xFF, 0x058f & 0xFF},
	{0x0591 & 0xFF, 0x05c7 & 0xFF},
	{0x05d0 & 0xFF, 0x05ea & 0xFF},
	{0x05ef & 0xFF, 0x05f4 & 0xFF},
	{0x0600 & 0xFF, 0x0604 & 0xFF},
	{0x0605 & 0xFF, 0x0605 & 0xFF},
	{0x0606 & 0xFF, 0x060b & 0xFF},
	{0x060c & 0xFF, 0x060c & 0xFF},
	{0x060d & 0xFF, 0x061a & 0xFF},
	{0x061b & 0xFF, 0x061b & 0xFF},
	{0x061c & 0xFF, 0x061e & 0xFF},
	{0x061f & 0xFF, 0x061f & 0xFF},
	{0x0620 & 0xFF, 0x063f & 0xFF},
	{0x0640 & 0xFF, 0x0640 & 0xFF},
	{0x0641 & 0xFF, 0x064a & 0xFF},
	{0x064b & 0xFF, 0x0655 & 0xFF},
	{0x0656 & 0xFF, 0x066f & 0xFF},
	{0x0670 & 0xFF, 0x0670 & 0xFF},
	{0x0671 & 0xFF, 0x06dc & 0xFF},
	{0x06dd & 0xFF, 0x06dd & 0xFF},
	{0x06de & 0xFF, 0x06ff & 0xFF},
	{0x0700 & 0xFF, 0x070d & 0xFF},
	{0x070f & 0xFF, 0x074a & 0xFF},
	{0x074d & 0xFF, 0x074f & 0xFF},
	{0x0750 & 0xFF, 0x077f & 0xFF},
	{0x0780 & 0xFF, 0x07b1 & 0xFF},
	{0x07c0 & 0xFF, 0x07fa & 0xFF},
	{0x07fd & 0xFF, 0x07ff & 0xFF},
	{0x0800 & 0xFF, 0x082d & 0xFF},
	{0x0830 & 0xFF, 0x083e & 0xFF},
	{0x0840 & 0xFF, 0x085b & 0xFF},
	{0x085e & 0xFF, 0x085e & 0xFF},
	{0x0860 & 0xFF, 0x086a & 0xFF},
	{0x0870 & 0xFF, 0x088e & 0xFF},
	{0x0890 & 0xFF, 0x0891 & 0xFF},
	{0x0897 & 0xFF, 0x08e1 & 0xFF},
	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
	{0x08e3 & 0xFF, 0x08ff & 0xFF},
	{0x0900 & 0xFF, 0x0950 & 0xFF},
	{0x0951 & 0xFF, 0x0954 & 0xFF},
	{0x0955 & 0xFF, 0x0963 & 0xFF},
	{0x0964 & 0xFF, 0x0965 & 0xFF},
	{0x0966 & 0xFF, 0x097f & 0xFF},
	{0x0980 & 0xFF, 0x0983 & 0xFF},
	{0x0985 & 0xFF, 0x098c & 0xFF},
	{0x098f & 0xFF, 0x0990 & 0xFF},
	{0x0993 & 0xFF, 0x09a8 & 0xFF},
	{0x09aa & 0xFF, 0x09b0 & 0xFF},
	{0x09b2 & 0xFF, 0x09b2 & 0xFF},
	{0x09b6 & 0xFF, 0x09b9 & 0xFF},
	{0x09bc & 0xFF, 0x09c4 & 0xFF},
	{0x09c7 & 0xFF, 0x09c8 & 0xFF},
	{0x09cb & 0xFF, 0x09ce & 0xFF},
	{0x09d7 & 0xFF, 0x09d7 & 0xFF},
	{0x09dc & 0xFF, 0x09dd & 0xFF},
	{0x09df & 0xFF, 0x09e3 & 0xFF},
	{0x09e6 & 0xFF, 0x09fe & 0xFF},
	{0x0a01 & 0xFF, 0x0a03 & 0xFF},
	{0x0a05 & 0xFF, 0x0a0a & 0xFF},
	{0x0a0f & 0xFF, 0x0a10 & 0xFF},
	{0x0a13 & 0xFF, 0x0a28 & 0xFF},
	{0x0a2a & 0xFF, 0x0a30 & 0xFF},
	{0x0a32 & 0xFF, 0x0a33 & 0xFF},
	{0x0a35 & 0xFF, 0x0a36 & 0xFF},
	{0x0a38 & 0xFF, 0x0a39 & 0xFF},
	{0x0a3c & 0xFF, 0x0a3c & 0xFF},
	{0x0a3e & 0xFF, 0x0a42 & 0xFF},
	{0x0a47 & 0xFF, 0x0a48 & 0xFF},
	{0x0a4b & 0xFF, 0x0a4d & 0xFF},
	{0x0a51 & 0xFF, 0x0a51 & 0xFF},
	{0x0a59 & 0xFF, 0x0a5c & 0xFF},
	{0x0a5e & 0xFF, 0x0a5e & 0xFF},
	{0x0a66 & 0xFF, 0x0a76 & 0xFF},
	{0x0a81 & 0xFF, 0x0a83 & 0xFF},
	{0x0a85 & 0xFF, 0x0a8d & 0xFF},
	{0x0a8f & 0xFF, 0x0a91 & 0xFF},
	{0x0a93 & 0xFF, 0x0aa8 & 0xFF},
	{0x0aaa & 0xFF, 0x0ab0 & 0xFF},
	{0x0ab2 & 0xFF, 0x0ab3 & 0xFF},
	{0x0ab5 & 0xFF, 0x0ab9 & 0xFF},
	{0x0abc & 0xFF, 0x0ac5 & 0xFF},
	{0x0ac7 & 0xFF, 0x0ac9 & 0xFF},
	{0x0acb & 0xFF, 0x0acd & 0xFF},
	{0x0ad0 & 0xFF, 0x0ad0 & 0xFF},
	{0x0ae0 & 0xFF, 0x0ae3 & 0xFF},
	{0x0ae6 & 0xFF, 0x0af1 & 0xFF},
	{0x0af9 & 0xFF, 0x0aff & 0xFF},
	{0x0b01 & 0xFF, 0x0b03 & 0xFF},
	{0x0b05 & 0xFF, 0x0b0c & 0xFF},
	{0x0b0f & 0xFF, 0x0b10 & 0xFF},
	{0x0b13 & 0xFF, 0x0b28 & 0xFF},
	{0x0b2a & 0xFF, 0x0b30 & 0xFF},
	{0x0b32 & 0xFF, 0x0b33 & 0xFF},
	{0x0b35 & 0xFF, 0x0b39 & 0xFF},
	{0x0b3c & 0xFF, 0x0b44 & 0xFF},
	{0x0b47 & 0xFF, 0x0b48 & 0xFF},
	{0x0b4b & 0xFF, 0x0b4d & 0xFF},
	{0x0b55 & 0xFF, 0x0b57 & 0xFF},
	{0x0b5c & 0xFF, 0x0b5d & 0xFF},
	{0x0b5f & 0xFF, 0x0b63 & 0xFF},
	{0x0b66 & 0xFF, 0x0b77 & 0xFF},
	{0x0b82 & 0xFF, 0x0b83 & 0xFF},
	{0x0b85 & 0xFF, 0x0b8a & 0xFF},
	{0x0b8e & 0xFF, 0x0b90 & 0xFF},
	{0x0b92 & 0xFF, 0x0b95 & 0xFF},
	{0x0b99 & 0xFF, 0x0b9a & 0xFF},
	{0x0b9c & 0xFF, 0x0b9c & 0xFF},
	{0x0b9e & 0xFF, 0x0b9f & 0xFF},
	{0x0ba3 & 0xFF, 0x0ba4 & 0xFF},
	{0x0ba8 & 0xFF, 0x0baa & 0xFF},
	{0x0bae & 0xFF, 0x0bb9 & 0xFF},
	{0x0bbe & 0xFF, 0x0bc2 & 0xFF},
	{0x0bc6 & 0xFF, 0x0bc8 & 0xFF},
	{0x0bca & 0xFF, 0x0bcd & 0xFF},
	{0x0bd0 & 0xFF, 0x0bd0 & 0xFF},
	{0x0bd7 & 0xFF, 0x0bd7 & 0xFF},
	{0x0be6 & 0xFF, 0x0bfa & 0xFF},
	{0x0c00 & 0xFF, 0x0c0c & 0xFF},
	{0x0c0e & 0xFF, 0x0c10 & 0xFF},
	{0x0c12 & 0xFF, 0x0c28 & 0xFF},
	{0x0c2a & 0xFF, 0x0c39 & 0xFF},
	{0x0c3c & 0xFF, 0x0c44 & 0xFF},
	{0x0c46 & 0xFF, 0x0c48 & 0xFF},
	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
	{0x0c58 & 0xFF, 0x0c5a & 0xFF},
	{0x0c5d & 0xFF, 0x0c5d & 0xFF},
	{0x0c60 & 0xFF, 0x0c63 & 0xFF},
	{0x0c66 & 0xFF, 0x0c6f & 0xFF},
	{0x0c77 & 0xFF, 0x0c7f & 0xFF},
	{0x0c80 & 0xFF, 0x0c8c & 0xFF},
	{0x0c8e & 0xFF, 0x0c90 & 0xFF},
	{0x0c92 & 0xFF, 0x0ca8 & 0xFF},
	{0x0caa & 0xFF, 0x0cb3 & 0xFF},
	{0x0cb5 & 0xFF, 0x0cb9 & 0xFF},
	{0x0cbc & 0xFF, 0x0cc4 & 0xFF},
	{0x0cc6 & 0xFF, 0x0cc8 & 0xFF},
	{0x0cca & 0xFF, 0x0ccd & 0xFF},
	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
	{0x0cdd & 0xFF, 0x0cde & 0xFF},
	{0x0ce0 & 0xFF, 0x0ce3 & 0xFF},
	{0x0ce6 & 0xFF, 0x0cef & 0xFF},
	{0x0cf1 & 0xFF, 0x0cf3 & 0xFF},
	{0x0d00 & 0xFF, 0x0d0c & 0xFF},
	{0x0d0e & 0xFF, 0x0d10 & 0xFF},
	{0x0d12 & 0xFF, 0x0d44 & 0xFF},
	{0x0d46 & 0xFF, 0x0d48 & 0xFF},
	{0x0d4a & 0xFF, 0x0d4f & 0xFF},
	{0x0d54 & 0xFF, 0x0d63 & 0xFF},
	{0x0d66 & 0xFF, 0x0d7f & 0xFF},
	{0x0d81 & 0xFF, 0x0d83 & 0xFF},
	{0x0d85 & 0xFF, 0x0d96 & 0xFF},
	{0x0d9a & 0xFF, 0x0db1 & 0xFF},
	{0x0db3 & 0xFF, 0x0dbb & 0xFF},
	{0x0dbd & 0xFF, 0x0dbd & 0xFF},
	{0x0dc0 & 0xFF, 0x0dc6 & 0xFF},
	{0x0dca & 0xFF, 0x0dca & 0xFF},
	{0x0dcf & 0xFF, 0x0dd4 & 0xFF},
	{0x0dd6 & 0xFF, 0x0dd6 & 0xFF},
	{0x0dd8 & 0xFF, 0x0ddf & 0xFF},
	{0x0de6 & 0xFF, 0x0def & 0xFF},
	{0x0df2 & 0xFF, 0x0df4 & 0xFF},
	{0x0e01 & 0xFF, 0x0e3a & 0xFF},
	{0x0e3f & 0xFF, 0x0e3f & 0xFF},
	{0x0e40 & 0xFF, 0x0e5b & 0xFF},
	{0x0e81 & 0xFF, 0x0e82 & 0xFF},
	{0x0e84 & 0xFF, 0x0e84 & 0xFF},
	{0x0e86 & 0xFF, 0x0e8a & 0xFF},
	{0x0e8c & 0xFF, 0x0ea3 & 0xFF},
	{0x0ea5 & 0xFF, 0x0ea5 & 0xFF},
	{0x0ea7 & 0xFF, 0x0ebd & 0xFF},
	{0x0ec0 & 0xFF, 0x0ec4 & 0xFF},
	{0x0ec6 & 0xFF, 0x0ec6 & 0xFF},
	{0x0ec8 & 0xFF, 0x0ece & 0xFF},
	{0x0ed0 & 0xFF, 0x0ed9 & 0xFF},
	{0x0edc & 0xFF, 0x0edf & 0xFF},
	{0x0f00 & 0xFF, 0x0f47 & 0xFF},
	{0x0f49 & 0xFF, 0x0f6c & 0xFF},
	{0x0f71 & 0xFF, 0x0f97 & 0xFF},
	{0x0f99 & 0xFF, 0x0fbc & 0xFF},
	{0x0fbe & 0xFF, 0x0fcc & 0xFF},
	{0x0fce & 0xFF, 0x0fd4 & 0xFF},
	{0x0fd5 & 0xFF, 0x0fd8 & 0xFF},
	{0x0fd9 & 0xFF, 0x0fda & 0xFF},
	{0x1000 & 0xFF, 0x109f & 0xFF},
	{0x10a0 & 0xFF, 0x10c5 & 0xFF},
	{0x10c7 & 0xFF, 0x10c7 & 0xFF},
	{0x10cd & 0xFF, 0x10cd & 0xFF},
	{0x10d0 & 0xFF, 0x10fa & 0xFF},
	{0x10fb & 0xFF, 0x10fb & 0xFF},
	{0x10fc & 0xFF, 0x10ff & 0xFF},
	{0x1100 & 0xFF, 0x11ff & 0xFF},
	{0x1200 & 0xFF, 0x1248 & 0xFF},
	{0x124a & 0xFF, 0x124d & 0xFF},
	{0x1250 & 0xFF, 0x1256 & 0xFF},
	{0x1258 & 0xFF, 0x1258 & 0xFF},
	{0x125a & 0xFF, 0x125d & 0xFF},
	{0x1260 & 0xFF, 0x1288 & 0xFF},
	{0x128a & 0xFF, 0x128d & 0xFF},
	{0x1290 & 0xFF, 0x12b0 & 0xFF},
	{0x12b2 & 0xFF, 0x12b5 & 0xFF},
	{0x12b8 & 0xFF, 0x12be & 0xFF},
	{0x12c0 & 0xFF, 0x12c0 & 0xFF},
	{0x12c2 & 0xFF, 0x12c5 & 0xFF},
	{0x12c8 & 0xFF, 0x12d6 & 0xFF},
	{0x12d8 & 0xFF, 0x12ff & 0xFF},
	{0x1300 & 0xFF, 0x1310 & 0xFF},
	{0x1312 & 0xFF, 0x1315 & 0xFF},
	{0x1318 & 0xFF, 0x135a & 0xFF},
	{0x135d & 0xFF, 0x137c & 0xFF},
	{0x1380 & 0xFF, 0x1399 & 0xFF},
	{0x13a0 & 0xFF, 0x13f5 & 0xFF},
	{0x13f8 & 0xFF, 0x13fd & 0xFF},
	{0x1400 & 0xFF, 0x14ff & 0xFF},
	{0x1500 & 0xFF, 0x15ff & 0xFF},
	{0x1600 & 0xFF, 0x167f & 0xFF},
	{0x1680 & 0xFF, 0x169c & 0xFF},
	{0x16a0 & 0xFF, 0x16ea & 0xFF},
	{0x16eb & 0xFF, 0x16ed & 0xFF},
	{0x16ee & 0xFF, 0x16f8 & 0xFF},
	{0x1700 & 0xFF, 0x1715 & 0xFF},
	{0x171f & 0xFF, 0x171f & 0xFF},
	{0x1720 & 0xFF, 0x1734 & 0xFF},
	{0x1735 & 0xFF, 0x1736 & 0xFF},
	{0x1740 & 0xFF, 0x1753 & 0xFF},
	{0x1760 & 0xFF, 0x176c & 0xFF},
	{0x176e & 0xFF, 0x1770 & 0xFF},
	{0x1772 & 0xFF, 0x1773 & 0xFF},
	{0x1780 & 0xFF, 0x17dd & 0xFF},
	{0x17e0 & 0xFF, 0x17e9 & 0xFF},
	{0x17f0 & 0xFF, 0x17f9 & 0xFF},
	{0x1800 & 0xFF, 0x1801 & 0xFF},
	{0x1802 & 0xFF, 0x1803 & 0xFF},
	{0x1804 & 0xFF, 0x1804 & 0xFF},
	{0x1805 & 0xFF, 0x1805 & 0xFF},
	{0x1806 & 0xFF, 0x1819 & 0xFF},
	{0x1820 & 0xFF, 0x1878 & 0xFF},
	{0x1880 & 0xFF, 0x18aa & 0xFF},
	{0x18b0 & 0xFF, 0x18f5 & 0xFF},
	{0x1900 & 0xFF, 0x191e & 0xFF},
	{0x1920 & 0xFF, 0x192b & 0xFF},
	{0x1930 & 0xFF, 0x193b & 0xFF},
	{0x1940 & 0xFF, 0x1940 & 0xFF},
	{0x1944 & 0xFF, 0x194f & 0xFF},
	{0x1950 & 0xFF, 0x196d & 0xFF},
	{0x1970 & 0xFF, 0x1974 & 0xFF},
	{0x1980 & 0xFF, 0x19ab & 0xFF},
	{0x19b0 & 0xFF, 0x19c9 & 0xFF},
	{0x19d0 & 0xFF, 0x19da & 0xFF},
	{0x19de & 0xFF, 0x19df & 0xFF},
	{0x19e0 & 0xFF, 0x19ff & 0xFF},
	{0x1a00 & 0xFF, 0x1a1b & 0xFF},
	{0x1a1e & 0xFF, 0x1a1f & 0xFF},
	{0x1a20 & 0xFF, 0x1a5e & 0xFF},
	{0x1a60 & 0xFF, 0x1a7c & 0xFF},
	{0x1a7f & 0xFF, 0x1a89 & 0xFF},
	{0x1a90 & 0xFF, 0x1a99 & 0xFF},
	{0x1aa0 & 0xFF, 0x1aad & 0xFF},
	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
	{0x1b00 & 0xFF, 0x1b4c & 0xFF},
	{0x1b4e & 0xFF, 0x1b7f & 0xFF},
	{0x1b80 & 0xFF, 0x1bbf & 0xFF},
	{0x1bc0 & 0xFF, 0x1bf3 & 0xFF},
	{0x1bfc & 0xFF, 0x1bff & 0xFF},
	{0x1c00 & 0xFF, 0x1c37 & 0xFF},
	{0x1c3b & 0xFF, 0x1c49 & 0xFF},
	{0x1c4d & 0xFF, 0x1c4f & 0xFF},
	{0x1c50 & 0xFF, 0x1c7f & 0xFF},
	{0x1c80 & 0xFF, 0x1c8a & 0xFF},
	{0x1c90 & 0xFF, 0x1cba & 0xFF},
	{0x1cbd & 0xFF, 0x1cbf & 0xFF},
	{0x1cc0 & 0xFF, 0x1cc7 & 0xFF},
	{0x1cd0 & 0xFF, 0x1cd2 & 0xFF},
	{0x1cd3 & 0xFF, 0x1cd3 & 0xFF},
	{0x1cd4 & 0xFF, 0x1ce0 & 0xFF},
	{0x1ce1 & 0xFF, 0x1ce1 & 0xFF},
	{0x1ce2 & 0xFF, 0x1ce8 & 0xFF},
	{0x1ce9 & 0xFF, 0x1cec & 0xFF},
	{0x1ced & 0xFF, 0x1ced & 0xFF},
	{0x1cee & 0xFF, 0x1cf3 & 0xFF},
	{0x1cf4 & 0xFF, 0x1cf4 & 0xFF},
	{0x1cf5 & 0xFF, 0x1cf7 & 0xFF},
	{0x1cf8 & 0xFF, 0x1cf9 & 0xFF},
	{0x1cfa & 0xFF, 0x1cfa & 0xFF},
	{0x1d00 & 0xFF, 0x1d25 & 0xFF},
	{0x1d26 & 0xFF, 0x1d2a & 0xFF},
	{0x1d2b & 0xFF, 0x1d2b & 0xFF},
	{0x1d2c & 0xFF, 0x1d5c & 0xFF},
	{0x1d5d & 0xFF, 0x1d61 & 0xFF},
	{0x1d62 & 0xFF, 0x1d65 & 0xFF},
	{0x1d66 & 0xFF, 0x1d6a & 0xFF},
	{0x1d6b & 0xFF, 0x1d77 & 0xFF},
	{0x1d78 & 0xFF, 0x1d78 & 0xFF},
	{0x1d79 & 0xFF, 0x1dbe & 0xFF},
	{0x1dbf & 0xFF, 0x1dbf & 0xFF},
	{0x1dc0 & 0xFF, 0x1dff & 0xFF},
	{0x1e00 & 0xFF, 0x1eff & 0xFF},
	{0x1f00 & 0xFF, 0x1f15 & 0xFF},
	{0x1f18 & 0xFF, 0x1f1d & 0xFF},
	{0x1f20 & 0xFF, 0x1f45 & 0xFF},
	{0x1f48 & 0xFF, 0x1f4d & 0xFF},
	{0x1f50 & 0xFF, 0x1f57 & 0xFF},
	{0x1f59 & 0xFF, 0x1f59 & 0xFF},
	{0x1f5b & 0xFF, 0x1f5b & 0xFF},
	{0x1f5d & 0xFF, 0x1f5d & 0xFF},
	{0x1f5f & 0xFF, 0x1f7d & 0xFF},
	{0x1f80 & 0xFF, 0x1fb4 & 0xFF},
	{0x1fb6 & 0xFF, 0x1fc4 & 0xFF},
	{0x1fc6 & 0xFF, 0x1fd3 & 0xFF},
	{0x1fd6 & 0xFF, 0x1fdb & 0xFF},
	{0x1fdd & 0xFF, 0x1fef & 0xFF},
	{0x1ff2 & 0xFF, 0x1ff4 & 0xFF},
	{0x1ff6 & 0xFF, 0x1ffe & 0xFF},
	{0x2000 & 0xFF, 0x200b & 0xFF},
	{0x200c & 0xFF, 0x200d & 0xFF},
	{0x200e & 0xFF, 0x2064 & 0xFF},
	{0x2066 & 0xFF, 0x2070 & 0xFF},
	{0x2071 & 0xFF, 0x2071 & 0xFF},
	{0x2074 & 0xFF, 0x207e & 0xFF},
	{0x207f & 0xFF, 0x207f & 0xFF},
	{0x2080 & 0xFF, 0x208e & 0xFF},
	{0x2090 & 0xFF, 0x209c & 0xFF},
	{0x20a0 & 0xFF, 0x20c0 & 0xFF},
	{0x20d0 & 0xFF, 0x20f0 & 0xFF},
	{0x2100 & 0xFF, 0x2125 & 0xFF},
	{0x2126 & 0xFF, 0x2126 & 0xFF},
	{0x2127 & 0xFF, 0x2129 & 0xFF},
	{0x212a & 0xFF, 0x212b & 0xFF},
	{0x212c & 0xFF, 0x2131 & 0xFF},
	{0x2132 & 0xFF, 0x2132 & 0xFF},
	{0x2133 & 0xFF, 0x214d & 0xFF},
	{0x214e & 0xFF, 0x214e & 0xFF},
	{0x214f & 0xFF, 0x215f & 0xFF},
	{0x2160 & 0xFF, 0x2188 & 0xFF},
	{0x2189 & 0xFF, 0x218b & 0xFF},
	{0x2190 & 0xFF, 0x21ff & 0xFF},
	{0x2200 & 0xFF, 0x22ff & 0xFF},
	{0x2300 & 0xFF, 0x23ff & 0xFF},
	{0x2400 & 0xFF, 0x2429 & 0xFF},
	{0x2440 & 0xFF, 0x244a & 0xFF},
	{0x2460 & 0xFF, 0x24ff & 0xFF},
	{0x2500 & 0xFF, 0x25ff & 0xFF},
	{0x2600 & 0xFF, 0x26ff & 0xFF},
	{0x2700 & 0xFF, 0x27ff & 0xFF},
	{0x2800 & 0xFF, 0x28ff & 0xFF},
	{0x2900 & 0xFF, 0x29ff & 0xFF},
	{0x2a00 & 0xFF, 0x2aff & 0xFF},
	{0x2b00 & 0xFF, 0x2b73 & 0xFF},
	{0x2b76 & 0xFF, 0x2b95 & 0xFF},
	{0x2b97 & 0xFF, 0x2bff & 0xFF},
	{0x2c00 & 0xFF, 0x2c5f & 0xFF},
	{0x2c60 & 0xFF, 0x2c7f & 0xFF},
	{0x2c80 & 0xFF, 0x2cf3 & 0xFF},
	{0x2cf9 & 0xFF, 0x2cff & 0xFF},
	{0x2d00 & 0xFF, 0x2d25 & 0xFF},
	{0x2d27 & 0xFF, 0x2d27 & 0xFF},
	{0x2d2d & 0xFF, 0x2d2d & 0xFF},
	{0x2d30 & 0xFF, 0x2d67 & 0xFF},
	{0x2d6f & 0xFF, 0x2d70 & 0xFF},
	{0x2d7f & 0xFF, 0x2d7f & 0xFF},
	{0x2d80 & 0xFF, 0x2d96 & 0xFF},
	{0x2da0 & 0xFF, 0x2da6 & 0xFF},
	{0x2da8 & 0xFF, 0x2dae & 0xFF},
	{0x2db0 & 0xFF, 0x2db6 & 0xFF},
	{0x2db8 & 0xFF, 0x2dbe & 0xFF},
	{0x2dc0 & 0xFF, 0x2dc6 & 0xFF},
	{0x2dc8 & 0xFF, 0x2dce & 0xFF},
	{0x2dd0 & 0xFF, 0x2dd6 & 0xFF},
	{0x2dd8 & 0xFF, 0x2dde & 0xFF},
	{0x2de0 & 0xFF, 0x2dff & 0xFF},
	{0x2e00 & 0xFF, 0x2e5d & 0xFF},
	{0x2e80 & 0xFF, 0x2e99 & 0xFF},
	{0x2e9b & 0xFF, 0x2ef3 & 0xFF},
	{0x2f00 & 0xFF, 0x2fd5 & 0xFF},
	{0x2ff0 & 0xFF, 0x2fff & 0xFF},
	{0x3000 & 0xFF, 0x3004 & 0xFF},
	{0x3005 & 0xFF, 0x3005 & 0xFF},
	{0x3006 & 0xFF, 0x3006 & 0xFF},
	{0x3007 & 0xFF, 0x3007 & 0xFF},
	{0x3008 & 0xFF, 0x3020 & 0xFF},
	{0x3021 & 0xFF, 0x3029 & 0xFF},
	{0x302a & 0xFF, 0x302d & 0xFF},
	{0x302e & 0xFF, 0x302f & 0xFF},
	{0x3030 & 0xFF, 0x3037 & 0xFF},
	{0x3038 & 0xFF, 0x303b & 0xFF},
	{0x303c & 0xFF, 0x303f & 0xFF},
	{0x3041 & 0xFF, 0x3096 & 0xFF},
	{0x3099 & 0xFF, 0x309a & 0xFF},
	{0x309b & 0xFF, 0x309c & 0xFF},
	{0x309d & 0xFF, 0x309f & 0xFF},
	{0x30a0 & 0xFF, 0x30a0 & 0xFF},
	{0x30a1 & 0xFF, 0x30fa & 0xFF},
	{0x30fb & 0xFF, 0x30fc & 0xFF},
	{0x30fd & 0xFF, 0x30ff & 0xFF},
	{0x3105 & 0xFF, 0x312f & 0xFF},
	{0x3131 & 0xFF, 0x318e & 0xFF},
	{0x3190 & 0xFF, 0x319f & 0xFF},
	{0x31a0 & 0xFF, 0x31bf & 0xFF},
	{0x31c0 & 0xFF, 0x31e5 & 0xFF},
	{0x31ef & 0xFF, 0x31ef & 0xFF},
	{0x31f0 & 0xFF, 0x31ff & 0xFF},
	{0x3200 & 0xFF, 0x321e & 0xFF},
	{0x3220 & 0xFF, 0x325f & 0xFF},
	{0x3260 & 0xFF, 0x327e & 0xFF},
	{0x327f & 0xFF, 0x32cf & 0xFF},
	{0x32d0 & 0xFF, 0x32fe & 0xFF},
	{0x32ff & 0xFF, 0x32ff & 0xFF},
	{0x3300 & 0xFF, 0x3357 & 0xFF},
	{0x3358 & 0xFF, 0x33ff & 0xFF},
	{0x3400 & 0xFF, 0x34ff & 0xFF},
	{0x3500 & 0xFF, 0x35ff & 0xFF},
	{0x3600 & 0xFF, 0x36ff & 0xFF},
	{0x3700 & 0xFF, 0x37ff & 0xFF},
	{0x3800 & 0xFF, 0x38ff & 0xFF},
	{0x3900 & 0xFF, 0x39ff & 0xFF},
	{0x3a00 & 0xFF, 0x3aff & 0xFF},
	{0x3b00 & 0xFF, 0x3bff & 0xFF},
	{0x3c00 & 0xFF, 0x3cff & 0xFF},
	{0x3d00 & 0xFF, 0x3dff & 0xFF},
	{0x3e00 & 0xFF, 0x3eff & 0xFF},
	{0x3f00 & 0xFF, 0x3fff & 0xFF},
	{0x4000 & 0xFF, 0x40ff & 0xFF},
	{0x4100 & 0xFF, 0x41ff & 0xFF},
	{0x4200 & 0xFF, 0x42ff & 0xFF},
	{0x4300 & 0xFF, 0x43ff & 0xFF},
	{0x4400 & 0xFF, 0x44ff & 0xFF},
	{0x4500 & 0xFF, 0x45ff & 0xFF},
	{0x4600 & 0xFF, 0x46ff & 0xFF},
	{0x4700 & 0xFF, 0x47ff & 0xFF},
	{0x4800 & 0xFF, 0x48ff & 0xFF},
	{0x4900 & 0xFF, 0x49ff & 0xFF},
	{0x4a00 & 0xFF, 0x4aff & 0xFF},
	{0x4b00 & 0xFF, 0x4bff & 0xFF},
	{0x4c00 & 0xFF, 0x4cff & 0xFF},
	{0x4d00 & 0xFF, 0x4dbf & 0xFF},
	{0x4dc0 & 0xFF, 0x4dff & 0xFF},
	{0x4e00 & 0xFF, 0x4eff & 0xFF},
	{0x4f00 & 0xFF, 0x4fff & 0xFF},
	{0x5000 & 0xFF, 0x50ff & 0xFF},
	{0x5100 & 0xFF, 0x51ff & 0xFF},
	{0x5200 & 0xFF, 0x52ff & 0xFF},
	{0x5300 & 0xFF, 0x53ff & 0xFF},
	{0x5400 & 0xFF, 0x54ff & 0xFF},
	{0x5500 & 0xFF, 0x55ff & 0xFF},
	{0x5600 & 0xFF, 0x56ff & 0xFF},
	{0x5700 & 0xFF, 0x57ff & 0xFF},
	{0x5800 & 0xFF, 0x58ff & 0xFF},
	{0x5900 & 0xFF, 0x59ff & 0xFF},
	{0x5a00 & 0xFF, 0x5aff & 0xFF},
	{0x5b00 & 0xFF, 0x5bff & 0xFF},
	{0x5c00 & 0xFF, 0x5cff & 0xFF},
	{0x5d00 & 0xFF, 0x5dff & 0xFF},
	{0x5e00 & 0xFF, 0x5eff & 0xFF},
	{0x5f00 & 0xFF, 0x5fff & 0xFF},
	{0x6000 & 0xFF, 0x60ff & 0xFF},
	{0x6100 & 0xFF, 0x61ff & 0xFF},
	{0x6200 & 0xFF, 0x62ff & 0xFF},
	{0x6300 & 0xFF, 0x63ff & 0xFF},
	{0x6400 & 0xFF, 0x64ff & 0xFF},
	{0x6500 & 0xFF, 0x65ff & 0xFF},
	{0x6600 & 0xFF, 0x66ff & 0xFF},
	{0x6700 & 0xFF, 0x67ff & 0xFF},
	{0x6800 & 0xFF, 0x68ff & 0xFF},
	{0x6900 & 0xFF, 0x69ff & 0xFF},
	{0x6a00 & 0xFF, 0x6aff & 0xFF},
	{0x6b00 & 0xFF, 0x6bff & 0xFF},
	{0x6c00 & 0xFF, 0x6cff & 0xFF},
	{0x6d00 & 0xFF, 0x6dff & 0xFF},
	{0x6e00 & 0xFF, 0x6eff & 0xFF},
	{0x6f00 & 0xFF, 0x6fff & 0xFF},
	{0x7000 & 0xFF, 0x70ff & 0xFF},
	{0x7100 & 0xFF, 0x71ff & 0xFF},
	{0x7200 & 0xFF, 0x72ff & 0xFF},
	{0x7300 & 0xFF, 0x73ff & 0xFF},
	{0x7400 & 0xFF, 0x74ff & 0xFF},
	{0x7500 & 0xFF, 0x75ff & 0xFF},
	{0x7600 & 0xFF, 0x76ff & 0xFF},
	{0x7700 & 0xFF, 0x77ff & 0xFF},
	{0x7800 & 0xFF, 0x78ff & 0xFF},
	{0x7900 & 0xFF, 0x79ff & 0xFF},
	{0x7a00 & 0xFF, 0x7aff & 0xFF},
	{0x7b00 & 0xFF, 0x7bff & 0xFF},
	{0x7c00 & 0xFF, 0x7cff & 0xFF},
	{0x7d00 & 0xFF, 0x7dff & 0xFF},
	{0x7e00 & 0xFF, 0x7eff & 0xFF},
	{0x7f00 & 0xFF, 0x7fff & 0xFF},
	{0x8000 & 0xFF, 0x80ff & 0xFF},
	{0x8100 & 0xFF, 0x81ff & 0xFF},
	{0x8200 & 0xFF, 0x82ff & 0xFF},
	{0x8300 & 0xFF, 0x83ff & 0xFF},
	{0x8400 & 0xFF, 0x84ff & 0xFF},
	{0x8500 & 0xFF, 0x85ff & 0xFF},
	{0x8600 & 0xFF, 0x86ff & 0xFF},
	{0x8700 & 0xFF, 0x87ff & 0xFF},
	{0x8800 & 0xFF, 0x88ff & 0xFF},
	{0x8900 & 0xFF, 0x89ff & 0xFF},
	{0x8a00 & 0xFF, 0x8aff & 0xFF},
	{0x8b00 & 0xFF, 0x8bff & 0xFF},
	{0x8c00 & 0xFF, 0x8cff & 0xFF},
	{0x8d00 & 0xFF, 0x8dff & 0xFF},
	{0x8e00 & 0xFF, 0x8eff & 0xFF},
	{0x8f00 & 0xFF, 0x8fff & 0xFF},
	{0x9000 & 0xFF, 0x90ff & 0xFF},
	{0x9100 & 0xFF, 0x91ff & 0xFF},
	{0x9200 & 0xFF, 0x92ff & 0xFF},
	{0x9300 & 0xFF, 0x93ff & 0xFF},
	{0x9400 & 0xFF, 0x94ff & 0xFF},
	{0x9500 & 0xFF, 0x95ff & 0xFF},
	{0x9600 & 0xFF, 0x96ff & 0xFF},
	{0x9700 & 0xFF, 0x97ff & 0xFF},
	{0x9800 & 0xFF, 0x98ff & 0xFF},
	{0x9900 & 0xFF, 0x99ff & 0xFF},
	{0x9a00 & 0xFF, 0x9aff & 0xFF},
	{0x9b00 & 0xFF, 0x9bff & 0xFF},
	{0x9c00 & 0xFF, 0x9cff & 0xFF},
	{0x9d00 & 0xFF, 0x9dff & 0xFF},
	{0x9e00 & 0xFF, 0x9eff & 0xFF},
	{0x9f00 & 0xFF, 0x9fff & 0xFF},
	{0xa000 & 0xFF, 0xa0ff & 0xFF},
	{0xa100 & 0xFF, 0xa1ff & 0xFF},
	{0xa200 & 0xFF, 0xa2ff & 0xFF},
	{0xa300 & 0xFF, 0xa3ff & 0xFF},
	{0xa400 & 0xFF, 0xa48c & 0xFF},
	{0xa490 & 0xFF, 0xa4c6 & 0xFF},
	{0xa4d0 & 0xFF, 0xa4ff & 0xFF},
	{0xa500 & 0xFF, 0xa5ff & 0xFF},
	{0xa600 & 0xFF, 0xa62b & 0xFF},
	{0xa640 & 0xFF, 0xa69f & 0xFF},
	{0xa6a0 & 0xFF, 0xa6f7 & 0xFF},
	{0xa700 & 0xFF, 0xa721 & 0xFF},
	{0xa722 & 0xFF, 0xa787 & 0xFF},
	{0xa788 & 0xFF, 0xa78a & 0xFF},
	{0xa78b & 0xFF, 0xa7cd & 0xFF},
	{0xa7d0 & 0xFF, 0xa7d1 & 0xFF},
	{0xa7d3 & 0xFF, 0xa7d3 & 0xFF},
	{0xa7d5 & 0xFF, 0xa7dc & 0xFF},
	{0xa7f2 & 0xFF, 0xa7ff & 0xFF},
	{0xa800 & 0xFF, 0xa82c & 0xFF},
	{0xa830 & 0xFF, 0xa839 & 0xFF},
	{0xa840 & 0xFF, 0xa877 & 0xFF},
	{0xa880 & 0xFF, 0xa8c5 & 0xFF},
	{0xa8ce & 0xFF, 0xa8d9 & 0xFF},
	{0xa8e0 & 0xFF, 0xa8ff & 0xFF},
	{0xa900 & 0xFF, 0xa92d & 0xFF},
	{0xa92e & 0xFF, 0xa92e & 0xFF},
	{0xa92f & 0xFF, 0xa92f & 0xFF},
	{0xa930 & 0xFF, 0xa953 & 0xFF},
	{0xa95f & 0xFF, 0xa95f & 0xFF},
	{0xa960 & 0xFF, 0xa97c & 0xFF},
	{0xa980 & 0xFF, 0xa9cd & 0xFF},
	{0xa9cf & 0xFF, 0xa9cf & 0xFF},
	{0xa9d0 & 0xFF, 0xa9d9 & 0xFF},
	{0xa9de & 0xFF, 0xa9df & 0xFF},
	{0xa9e0 & 0xFF, 0xa9fe & 0xFF},
	{0xaa00 & 0xFF, 0xaa36 & 0xFF},
	{0xaa40 & 0xFF, 0xaa4d & 0xFF},
	{0xaa50 & 0xFF, 0xaa59 & 0xFF},
	{0xaa5c & 0xFF, 0xaa5f & 0xFF},
	{0xaa60 & 0xFF, 0xaa7f & 0xFF},
	{0xaa80 & 0xFF, 0xaac2 & 0xFF},
	{0xaadb & 0xFF, 0xaadf & 0xFF},
	{0xaae0 & 0xFF, 0xaaf6 & 0xFF},
	{0xab01 & 0xFF, 0xab06 & 0xFF},
	{0xab09 & 0xFF, 0xab0e & 0xFF},
	{0xab11 & 0xFF, 0xab16 & 0xFF},
	{0xab20 & 0xFF, 0xab26 & 0xFF},
	{0xab28 & 0xFF, 0xab2e & 0xFF},
	{0xab30 & 0xFF, 0xab5a & 0xFF},
	{0xab5b & 0xFF, 0xab5b & 0xFF},
	{0xab5c & 0xFF, 0xab64 & 0xFF},
	{0xab65 & 0xFF, 0xab65 & 0xFF},
	{0xab66 & 0xFF, 0xab69 & 0xFF},
	{0xab6a & 0xFF, 0xab6b & 0xFF},
	{0xab70 & 0xFF, 0xabbf & 0xFF},
	{0xabc0 & 0xFF, 0xabed & 0xFF},
	{0xabf0 & 0xFF, 0xabf9 & 0xFF},
	{0xac00 & 0xFF, 0xacff & 0xFF},
	{0xad00 & 0xFF, 0xadff & 0xFF},
	{0xae00 & 0xFF, 0xaeff & 0xFF},
	{0xaf00 & 0xFF, 0xafff & 0xFF},
	{0xb000 & 0xFF, 0xb0ff & 0xFF},
	{0xb100 & 0xFF, 0xb1ff & 0xFF},
	{0xb200 & 0xFF, 0xb2ff & 0xFF},
	{0xb300 & 0xFF, 0xb3ff & 0xFF},
	{0xb400 & 0xFF, 0xb4ff & 0xFF},
	{0xb500 & 0xFF, 0xb5ff & 0xFF},
	{0xb600 & 0xFF, 0xb6ff & 0xFF},
	{0xb700 & 0xFF, 0xb7ff & 0xFF},
	{0xb800 & 0xFF, 0xb8ff & 0xFF},
	{0xb900 & 0xFF, 0xb9ff & 0xFF},
	{0xba00 & 0xFF, 0xbaff & 0xFF},
	{0xbb00 & 0xFF, 0xbbff & 0xFF},
	{0xbc00 & 0xFF, 0xbcff & 0xFF},
	{0xbd00 & 0xFF, 0xbdff & 0xFF},
	{0xbe00 & 0xFF, 0xbeff & 0xFF},
	{0xbf00 & 0xFF, 0xbfff & 0xFF},
	{0xc000 & 0xFF, 0xc0ff & 0xFF},
	{0xc100 & 0xFF, 0xc1ff & 0xFF},
	{0xc200 & 0xFF, 0xc2ff & 0xFF},
	{0xc300 & 0xFF, 0xc3ff & 0xFF},
	{0xc400 & 0xFF, 0xc4ff & 0xFF},
	{0xc500 & 0xFF, 0xc5ff & 0xFF},
	{0xc600 & 0xFF, 0xc6ff & 0xFF},
	{0xc700 & 0xFF, 0xc7ff & 0xFF},
	{0xc800 & 0xFF, 0xc8ff & 0xFF},
	{0xc900 & 0xFF, 0xc9ff & 0xFF},
	{0xca00 & 0xFF, 0xcaff & 0xFF},
	{0xcb00 & 0xFF, 0xcbff & 0xFF},
	{0xcc00 & 0xFF, 0xccff & 0xFF},
	{0xcd00 & 0xFF, 0xcdff & 0xFF},
	{0xce00 & 0xFF, 0xceff & 0xFF},
	{0xcf00 & 0xFF, 0xcfff & 0xFF},
	{0xd000 & 0xFF, 0xd0ff & 0xFF},
	{0xd100 & 0xFF, 0xd1ff & 0xFF},
	{0xd200 & 0xFF, 0xd2ff & 0xFF},
	{0xd300 & 0xFF, 0xd3ff & 0xFF},
	{0xd400 & 0xFF, 0xd4ff & 0xFF},
	{0xd500 & 0xFF, 0xd5ff & 0xFF},
	{0xd600 & 0xFF, 0xd6ff & 0xFF},
	{0xd700 & 0xFF, 0xd7a3 & 0xFF},
	{0xd7b0 & 0xFF, 0xd7c6 & 0xFF},
	{0xd7cb & 0xFF, 0xd7fb & 0xFF},
	{0xf900 & 0xFF, 0xf9ff & 0xFF},
	{0xfa00 & 0xFF, 0xfa6d & 0xFF},
	{0xfa70 & 0xFF, 0xfad9 & 0xFF},
	{0xfb00 & 0xFF, 0xfb06 & 0xFF},
	{0xfb13 & 0xFF, 0xfb17 & 0xFF},
	{0xfb1d & 0xFF, 0xfb36 & 0xFF},
	{0xfb38 & 0xFF, 0xfb3c & 0xFF},
	{0xfb3e & 0xFF, 0xfb3e & 0xFF},
	{0xfb40 & 0xFF, 0xfb41 & 0xFF},
	{0xfb43 & 0xFF, 0xfb44 & 0xFF},
	{0xfb46 & 0xFF, 0xfb4f & 0xFF},
	{0xfb50 & 0xFF, 0xfbc2 & 0xFF},
	{0xfbd3 & 0xFF, 0xfbff & 0xFF},
	{0xfc00 & 0xFF, 0xfcff & 0xFF},
	{0xfd00 & 0xFF, 0xfd3d & 0xFF},
	{0xfd3e & 0xFF, 0xfd3f & 0xFF},
	{0xfd40 & 0xFF, 0xfd8f & 0xFF},
	{0xfd92 & 0xFF, 0xfdc7 & 0xFF},
	{0xfdcf & 0xFF, 0xfdcf & 0xFF},
	{0xfdf0 & 0xFF, 0xfdff & 0xFF},
	{0xfe00 & 0xFF, 0xfe0f & 0xFF},
	{0xfe10 & 0xFF, 0xfe19 & 0xFF},
	{0xfe20 & 0xFF, 0xfe2d & 0xFF},
	{0xfe2e & 0xFF, 0xfe2f & 0xFF},
	{0xfe30 & 0xFF, 0xfe52 & 0xFF},
	{0xfe54 & 0xFF, 0xfe66 & 0xFF},
	{0xfe68 & 0xFF, 0xfe6b & 0xFF},
	{0xfe70 & 0xFF, 0xfe74 & 0xFF},
	{0xfe76 & 0xFF, 0xfefc & 0xFF},
	{0xfeff & 0xFF, 0xfeff & 0xFF},
	{0xff01 & 0xFF, 0xff20 & 0xFF},
	{0xff21 & 0xFF, 0xff3a & 0xFF},
	{0xff3b & 0xFF, 0xff40 & 0xFF},
	{0xff41 & 0xFF, 0xff5a & 0xFF},
	{0xff5b & 0xFF, 0xff65 & 0xFF},
	{0xff66 & 0xFF, 0xff6f & 0xFF},
	{0xff70 & 0xFF, 0xff70 & 0xFF},
	{0xff71 & 0xFF, 0xff9d & 0xFF},
	{0xff9e & 0xFF, 0xff9f & 0xFF},
	{0xffa0 & 0xFF, 0xffbe & 0xFF},
	{0xffc2 & 0xFF, 0xffc7 & 0xFF},
	{0xffca & 0xFF, 0xffcf & 0xFF},
	{0xffd2 & 0xFF, 0xffd7 & 0xFF},
	{0xffda & 0xFF, 0xffdc & 0xFF},
	{0xffe0 & 0xFF, 0xffe6 & 0xFF},
	{0xffe8 & 0xFF, 0xffee & 0xFF},
	{0xfff9 & 0xFF, 0xfffd & 0xFF},
	{0x10000 & 0xFF, 0x1000b & 0xFF},
	{0x1000d & 0xFF, 0x10026 & 0xFF},
	{0x10028 & 0xFF, 0x1003a & 0xFF},
	{0x1003c & 0xFF, 0x1003d & 0xFF},
	{0x1003f & 0xFF, 0x1004d & 0xFF},
	{0x10050 & 0xFF, 0x1005d & 0xFF},
	{0x10080 & 0xFF, 0x100fa & 0xFF},
	{0x10100 & 0xFF, 0x10102 & 0xFF},
	{0x10107 & 0xFF, 0x10133 & 0xFF},
	{0x10137 & 0xFF, 0x1013f & 0xFF},
	{0x10140 & 0xFF, 0x1018e & 0xFF},
	{0x10190 & 0xFF, 0x1019c & 0xFF},
	{0x101a0 & 0xFF, 0x101a0 & 0xFF},
	{0x101d0 & 0xFF, 0x101fc & 0xFF},
	{0x101fd & 0xFF, 0x101fd & 0xFF},
	{0x10280 & 0xFF, 0x1029c & 0xFF},
	{0x102a0 & 0xFF, 0x102d0 & 0xFF},
	{0x102e0 & 0xFF, 0x102e0 & 0xFF},
	{0x102e1 & 0xFF, 0x102fb & 0xFF},
	{0x10300 & 0xFF, 0x10323 & 0xFF},
	{0x1032d & 0xFF, 0x1032f & 0xFF},
	{0x10330 & 0xFF, 0x1034a & 0xFF},
	{0x10350 & 0xFF, 0x1037a & 0xFF},
	{0x10380 & 0xFF, 0x1039d & 0xFF},
	{0x1039f & 0xFF, 0x1039f & 0xFF},
	{0x103a0 & 0xFF, 0x103c3 & 0xFF},
	{0x103c8 & 0xFF, 0x103d5 & 0xFF},
	{0x10400 & 0xFF, 0x1044f & 0xFF},
	{0x10450 & 0xFF, 0x1047f & 0xFF},
	{0x10480 & 0xFF, 0x1049d & 0xFF},
	{0x104a0 & 0xFF, 0x104a9 & 0xFF},
	{0x104b0 & 0xFF, 0x104d3 & 0xFF},
	{0x104d8 & 0xFF, 0x104fb & 0xFF},
	{0x10500 & 0xFF, 0x10527 & 0xFF},
	{0x10530 & 0xFF, 0x10563 & 0xFF},
	{0x1056f & 0xFF, 0x1056f & 0xFF},
	{0x10570 & 0xFF, 0x1057a & 0xFF},
	{0x1057c & 0xFF, 0x1058a & 0xFF},
	{0x1058c & 0xFF, 0x10592 & 0xFF},
	{0x10594 & 0xFF, 0x10595 & 0xFF},
	{0x10597 & 0xFF, 0x105a1 & 0xFF},
	{0x105a3 & 0xFF, 0x105b1 & 0xFF},
	{0x105b3 & 0xFF, 0x105b9 & 0xFF},
	{0x105bb & 0xFF, 0x105bc & 0xFF},
	{0x105c0 & 0xFF, 0x105f3 & 0xFF},
	{0x10600 & 0xFF, 0x106ff & 0xFF},
	{0x10700 & 0xFF, 0x10736 & 0xFF},
	{0x10740 & 0xFF, 0x10755 & 0xFF},
	{0x10760 & 0xFF, 0x10767 & 0xFF},
	{0x10780 & 0xFF, 0x10785 & 0xFF},
	{0x10787 & 0xFF, 0x107b0 & 0xFF},
	{0x107b2 & 0xFF, 0x107ba & 0xFF},
	{0x10800 & 0xFF, 0x10805 & 0xFF},
	{0x10808 & 0xFF, 0x10808 & 0xFF},
	{0x1080a & 0xFF, 0x10835 & 0xFF},
	{0x10837 & 0xFF, 0x10838 & 0xFF},
	{0x1083c & 0xFF, 0x1083c & 0xFF},
	{0x1083f & 0xFF, 0x1083f & 0xFF},
	{0x10840 & 0xFF, 0x10855 & 0xFF},
	{0x10857 & 0xFF, 0x1085f & 0xFF},
	{0x10860 & 0xFF, 0x1087f & 0xFF},
	{0x10880 & 0xFF, 0x1089e & 0xFF},
	{0x108a7 & 0xFF, 0x108af & 0xFF},
	{0x108e0 & 0xFF, 0x108f2 & 0xFF},
	{0x108f4 & 0xFF, 0x108f5 & 0xFF},
	{0x108fb & 0xFF, 0x108ff & 0xFF},
	{0x10900 & 0xFF, 0x1091b & 0xFF},
	{0x1091f & 0xFF, 0x1091f & 0xFF},
	{0x10920 & 0xFF, 0x10939 & 0xFF},
	{0x1093f & 0xFF, 0x1093f & 0xFF},
	{0x10980 & 0xFF, 0x1099f & 0xFF},
	{0x109a0 & 0xFF, 0x109b7 & 0xFF},
	{0x109bc & 0xFF, 0x109cf & 0xFF},
	{0x109d2 & 0xFF, 0x109ff & 0xFF},
	{0x10a00 & 0xFF, 0x10a03 & 0xFF},
	{0x10a05 & 0xFF, 0x10a06 & 0xFF},
	{0x10a0c & 0xFF, 0x10a13 & 0xFF},
	{0x10a15 & 0xFF, 0x10a17 & 0xFF},
	{0x10a19 & 0xFF, 0x10a35 & 0xFF},
	{0x10a38 & 0xFF, 0x10a3a & 0xFF},
	{0x10a3f & 0xFF, 0x10a48 & 0xFF},
	{0x10a50 & 0xFF, 0x10a58 & 0xFF},
	{0x10a60 & 0xFF, 0x10a7f & 0xFF},
	{0x10a80 & 0xFF, 0x10a9f & 0xFF},
	{0x10ac0 & 0xFF, 0x10ae6 & 0xFF},
	{0x10aeb & 0xFF, 0x10af6 & 0xFF},
	{0x10b00 & 0xFF, 0x10b35 & 0xFF},
	{0x10b39 & 0xFF, 0x10b3f & 0xFF},
	{0x10b40 & 0xFF, 0x10b55 & 0xFF},
	{0x10b58 & 0xFF, 0x10b5f & 0xFF},
	{0x10b60 & 0xFF, 0x10b72 & 0xFF},
	{0x10b78 & 0xFF, 0x10b7f & 0xFF},
	{0x10b80 & 0xFF, 0x10b91 & 0xFF},
	{0x10b99 & 0xFF, 0x10b9c & 0xFF},
	{0x10ba9 & 0xFF, 0x10baf & 0xFF},
	{0x10c00 & 0xFF, 0x10c48 & 0xFF},
	{0x10c80 & 0xFF, 0x10cb2 & 0xFF},
	{0x10cc0 & 0xFF, 0x10cf2 & 0xFF},
	{0x10cfa & 0xFF, 0x10cff & 0xFF},
	{0x10d00 & 0xFF, 0x10d27 & 0xFF},
	{0x10d30 & 0xFF, 0x10d39 & 0xFF},
	{0x10d40 & 0xFF, 0x10d65 & 0xFF},
	{0x10d69 & 0xFF, 0x10d85 & 0xFF},
	{0x10d8e & 0xFF, 0x10d8f & 0xFF},
	{0x10e60 & 0xFF, 0x10e7e & 0xFF},
	{0x10e80 & 0xFF, 0x10ea9 & 0xFF},
	{0x10eab & 0xFF, 0x10ead & 0xFF},
	{0x10eb0 & 0xFF, 0x10eb1 & 0xFF},
	{0x10ec2 & 0xFF, 0x10ec4 & 0xFF},
	{0x10efc & 0xFF, 0x10eff & 0xFF},
	{0x10f00 & 0xFF, 0x10f27 & 0xFF},
	{0x10f30 & 0xFF, 0x10f59 & 0xFF},
	{0x10f70 & 0xFF, 0x10f89 & 0xFF},
	{0x10fb0 & 0xFF, 0x10fcb & 0xFF},
	{0x10fe0 & 0xFF, 0x10ff6 & 0xFF},
	{0x11000 & 0xFF, 0x1104d & 0xFF},
	{0x11052 & 0xFF, 0x11075 & 0xFF},
	{0x1107f & 0xFF, 0x1107f & 0xFF},
	{0x11080 & 0xFF, 0x110c2 & 0xFF},
	{0x110cd & 0xFF, 0x110cd & 0xFF},
	{0x110d0 & 0xFF, 0x110e8 & 0xFF},
	{0x110f0 & 0xFF, 0x110f9 & 0xFF},
	{0x11100 & 0xFF, 0x11134 & 0xFF},
	{0x11136 & 0xFF, 0x11147 & 0xFF},
	{0x11150 & 0xFF, 0x11176 & 0xFF},
	{0x11180 & 0xFF, 0x111df & 0xFF},
	{0x111e1 & 0xFF, 0x111f4 & 0xFF},
	{0x11200 & 0xFF, 0x11211 & 0xFF},
	{0x11213 & 0xFF, 0x11241 & 0xFF},
	{0x11280 & 0xFF, 0x11286 & 0xFF},
	{0x11288 & 0xFF, 0x11288 & 0xFF},
	{0x1128a & 0xFF, 0x1128d & 0xFF},
	{0x1128f & 0xFF, 0x1129d & 0xFF},
	{0x1129f & 0xFF, 0x112a9 & 0xFF},
	{0x112b0 & 0xFF, 0x112ea & 0xFF},
	{0x112f0 & 0xFF, 0x112f9 & 0xFF},
	{0x11300 & 0xFF, 0x11303 & 0xFF},
	{0x11305 & 0xFF, 0x1130c & 0xFF},
	{0x1130f & 0xFF, 0x11310 & 0xFF},
	{0x11313 & 0xFF, 0x11328 & 0xFF},
	{0x1132a & 0xFF, 0x11330 & 0xFF},
	{0x11332 & 0xFF, 0x11333 & 0xFF},
	{0x11335 & 0xFF, 0x11339 & 0xFF},
	{0x1133b & 0xFF, 0x1133b & 0xFF},
	{0x1133c & 0xFF, 0x11344 & 0xFF},
	{0x11347 & 0xFF, 0x11348 & 0xFF},
	{0x1134b & 0xFF, 0x1134d & 0xFF},
	{0x11350 & 0xFF, 0x11350 & 0xFF},
	{0x11357 & 0xFF, 0x11357 & 0xFF},
	{0x1135d & 0xFF, 0x11363 & 0xFF},
	{0x11366 & 0xFF, 0x1136c & 0xFF},
	{0x11370 & 0xFF, 0x11374 & 0xFF},
	{0x11380 & 0xFF, 0x11389 & 0xFF},
	{0x1138b & 0xFF, 0x1138b & 0xFF},
	{0x1138e & 0xFF, 0x1138e & 0xFF},
	{0x11390 & 0xFF, 0x113b5 & 0xFF},
	{0x113b7 & 0xFF, 0x113c0 & 0xFF},
	{0x113c2 & 0xFF, 0x113c2 & 0xFF},
	{0x113c5 & 0xFF, 0x113c5 & 0xFF},
	{0x113c7 & 0xFF, 0x113ca & 0xFF},
	{0x113cc & 0xFF, 0x113d5 & 0xFF},
	{0x113d7 & 0xFF, 0x113d8 & 0xFF},
	{0x113e1 & 0xFF, 0x113e2 & 0xFF},
	{0x11400 & 0xFF, 0x1145b & 0xFF},
	{0x1145d & 0xFF, 0x11461 & 0xFF},
	{0x11480 & 0xFF, 0x114c7 & 0xFF},
	{0x114d0 & 0xFF, 0x114d9 & 0xFF},
	{0x11580 & 0xFF, 0x115b5 & 0xFF},
	{0x115b8 & 0xFF, 0x115dd & 0xFF},
	{0x11600 & 0xFF, 0x11644 & 0xFF},
	{0x11650 & 0xFF, 0x11659 & 0xFF},
	{0x11660 & 0xFF, 0x1166c & 0xFF},
	{0x11680 & 0xFF, 0x116b9 & 0xFF},
	{0x116c0 & 0xFF, 0x116c9 & 0xFF},
	{0x116d0 & 0xFF, 0x116e3 & 0xFF},
	{0x11700 & 0xFF, 0x1171a & 0xFF},
	{0x1171d & 0xFF, 0x1172b & 0xFF},
	{0x11730 & 0xFF, 0x11746 & 0xFF},
	{0x11800 & 0xFF, 0x1183b & 0xFF},
	{0x118a0 & 0xFF, 0x118f2 & 0xFF},
	{0x118ff & 0xFF, 0x118ff & 0xFF},
	{0x11900 & 0xFF, 0x11906 & 0xFF},
	{0x11909 & 0xFF, 0x11909 & 0xFF},
	{0x1190c & 0xFF, 0x11913 & 0xFF},
	{0x11915 & 0xFF, 0x11916 & 0xFF},
	{0x11918 & 0xFF, 0x11935 & 0xFF},
	{0x11937 & 0xFF, 0x11938 & 0xFF},
	{0x1193b & 0xFF, 0x11946 & 0xFF},
	{0x11950 & 0xFF, 0x11959 & 0xFF},
	{0x119a0 & 0xFF, 0x119a7 & 0xFF},
	{0x119aa & 0xFF, 0x119d7 & 0xFF},
	{0x119da & 0xFF, 0x119e4 & 0xFF},
	{0x11a00 & 0xFF, 0x11a47 & 0xFF},
	{0x11a50 & 0xFF, 0x11aa2 & 0xFF},
	{0x11ab0 & 0xFF, 0x11abf & 0xFF},
	{0x11ac0 & 0xFF, 0x11af8 & 0xFF},
	{0x11b00 & 0xFF, 0x11b09 & 0xFF},
	{0x11bc0 & 0xFF, 0x11be1 & 0xFF},
	{0x11bf0 & 0xFF, 0x11bf9 & 0xFF},
	{0x11c00 & 0xFF, 0x11c08 & 0xFF},
	{0x11c0a & 0xFF, 0x11c36 & 0xFF},
	{0x11c38 & 0xFF, 0x11c45 & 0xFF},
	{0x11c50 & 0xFF, 0x11c6c & 0xFF},
	{0x11c70 & 0xFF, 0x11c8f & 0xFF},
	{0x11c92 & 0xFF, 0x11ca7 & 0xFF},
	{0x11ca9 & 0xFF, 0x11cb6 & 0xFF},
	{0x11d00 & 0xFF, 0x11d06 & 0xFF},
	{0x11d08 & 0xFF, 0x11d09 & 0xFF},
	{0x11d0b & 0xFF, 0x11d36 & 0xFF},
	{0x11d3a & 0xFF, 0x11d3a & 0xFF},
	{0x11d3c & 0xFF, 0x11d3d & 0xFF},
	{0x11d3f & 0xFF, 0x11d47 & 0xFF},
	{0x11d50 & 0xFF, 0x11d59 & 0xFF},
	{0x11d60 & 0xFF, 0x11d65 & 0xFF},
	{0x11d67 & 0xFF, 0x11d68 & 0xFF},
	{0x11d6a & 0xFF, 0x11d8e & 0xFF},
	{0x11d90 & 0xFF, 0x11d91 & 0xFF},
	{0x11d93 & 0xFF, 0x11d98 & 0xFF},
	{0x11da0 & 0xFF, 0x11da9 & 0xFF},
	{0x11ee0 & 0xFF, 0x11ef8 & 0xFF},
	{0x11f00 & 0xFF, 0x11f10 & 0xFF},
	{0x11f12 & 0xFF, 0x11f3a & 0xFF},
	{0x11f3e & 0xFF, 0x11f5a & 0xFF},
	{0x11fb0 & 0xFF, 0x11fb0 & 0xFF},
	{0x11fc0 & 0xFF, 0x11ff1 & 0xFF},
	{0x11fff & 0xFF, 0x11fff & 0xFF},
	{0x12000 & 0xFF, 0x120ff & 0xFF},
	{0x12100 & 0xFF, 0x121ff & 0xFF},
	{0x12200 & 0xFF, 0x122ff & 0xFF},
	{0x12300 & 0xFF, 0x12399 & 0xFF},
	{0x12400 & 0xFF, 0x1246e & 0xFF},
	{0x12470 & 0xFF, 0x12474 & 0xFF},
	{0x12480 & 0xFF, 0x124ff & 0xFF},
	{0x12500 & 0xFF, 0x12543 & 0xFF},
	{0x12f90 & 0xFF, 0x12ff2 & 0xFF},
	{0x13000 & 0xFF, 0x130ff & 0xFF},
	{0x13100 & 0xFF, 0x131ff & 0xFF},
	{0x13200 & 0xFF, 0x132ff & 0xFF},
	{0x13300 & 0xFF, 0x133ff & 0xFF},
	{0x13400 & 0xFF, 0x13455 & 0xFF},
	{0x13460 & 0xFF, 0x134ff & 0xFF},
	{0x13500 & 0xFF, 0x135ff & 0xFF},
	{0x13600 & 0xFF, 0x136ff & 0xFF},
	{0x13700 & 0xFF, 0x137ff & 0xFF},
	{0x13800 & 0xFF, 0x138ff & 0xFF},
	{0x13900 & 0xFF, 0x139ff & 0xFF},
	{0x13a00 & 0xFF, 0x13aff & 0xFF},
	{0x13b00 & 0xFF, 0x13bff & 0xFF},
	{0x13c00 & 0xFF, 0x13cff & 0xFF},
	{0x13d00 & 0xFF, 0x13dff & 0xFF},
	{0x13e00 & 0xFF, 0x13eff & 0xFF},
	{0x13f00 & 0xFF, 0x13fff & 0xFF},
	{0x14000 & 0xFF, 0x140ff & 0xFF},
	{0x14100 & 0xFF, 0x141ff & 0xFF},
	{0x14200 & 0xFF, 0x142ff & 0xFF},
	{0x14300 & 0xFF, 0x143fa & 0xFF},
	{0x14400 & 0xFF, 0x144ff & 0xFF},
	{0x14500 & 0xFF, 0x145ff & 0xFF},
	{0x14600 & 0xFF, 0x14646 & 0xFF},
	{0x16100 & 0xFF, 0x16139 & 0xFF},
	{0x16800 & 0xFF, 0x168ff & 0xFF},
	{0x16900 & 0xFF, 0x169ff & 0xFF},
	{0x16a00 & 0xFF, 0x16a38 & 0xFF},
	{0x16a40 & 0xFF, 0x16a5e & 0xFF},
	{0x16a60 & 0xFF, 0x16a69 & 0xFF},
	{0x16a6e & 0xFF, 0x16a6f & 0xFF},
	{0x16a70 & 0xFF, 0x16abe & 0xFF},
	{0x16ac0 & 0xFF, 0x16ac9 & 0xFF},
	{0x16ad0 & 0xFF, 0x16aed & 0xFF},
	{0x16af0 & 0xFF, 0x16af5 & 0xFF},
	{0x16b00 & 0xFF, 0x16b45 & 0xFF},
	{0x16b50 & 0xFF, 0x16b59 & 0xFF},
	{0x16b5b & 0xFF, 0x16b61 & 0xFF},
	{0x16b63 & 0xFF, 0x16b77 & 0xFF},
	{0x16b7d & 0xFF, 0x16b8f & 0xFF},
	{0x16d40 & 0xFF, 0x16d79 & 0xFF},
	{0x16e40 & 0xFF, 0x16e9a & 0xFF},
	{0x16f00 & 0xFF, 0x16f4a & 0xFF},
	{0x16f4f & 0xFF, 0x16f87 & 0xFF},
	{0x16f8f & 0xFF, 0x16f9f & 0xFF},
	{0x16fe0 & 0xFF, 0x16fe0 & 0xFF},
	{0x16fe1 & 0xFF, 0x16fe1 & 0xFF},
	{0x16fe2 & 0xFF, 0x16fe3 & 0xFF},
	{0x16fe4 & 0xFF, 0x16fe4 & 0xFF},
	{0x16ff0 & 0xFF, 0x16ff1 & 0xFF},
	{0x17000 & 0xFF, 0x170ff & 0xFF},
	{0x17100 & 0xFF, 0x171ff & 0xFF},
	{0x17200 & 0xFF, 0x172ff & 0xFF},
	{0x17300 & 0xFF, 0x173ff & 0xFF},
	{0x17400 & 0xFF, 0x174ff & 0xFF},
	{0x17500 & 0xFF, 0x175ff & 0xFF},
	{0x17600 & 0xFF, 0x176ff & 0xFF},
	{0x17700 & 0xFF, 0x177ff & 0xFF},
	{0x17800 & 0xFF, 0x178ff & 0xFF},
	{0x17900 & 0xFF, 0x179ff & 0xFF},
	{0x17a00 & 0xFF, 0x17aff & 0xFF},
	{0x17b00 & 0xFF, 0x17bff & 0xFF},
	{0x17c00 & 0xFF, 0x17cff & 0xFF},
	{0x17d00 & 0xFF, 0x17dff & 0xFF},
	{0x17e00 & 0xFF, 0x17eff & 0xFF},
	{0x17f00 & 0xFF, 0x17fff & 0xFF},
	{0x18000 & 0xFF, 0x180ff & 0xFF},
	{0x18100 & 0xFF, 0x181ff & 0xFF},
	{0x18200 & 0xFF, 0x182ff & 0xFF},
	{0x18300 & 0xFF, 0x183ff & 0xFF},
	{0x18400 & 0xFF, 0x184ff & 0xFF},
	{0x18500 & 0xFF, 0x185ff & 0xFF},
	{0x18600 & 0xFF, 0x186ff & 0xFF},
	{0x18700 & 0xFF, 0x187f7 & 0xFF},
	{0x18800 & 0xFF, 0x188ff & 0xFF},
	{0x18900 & 0xFF, 0x189ff & 0xFF},
	{0x18a00 & 0xFF, 0x18aff & 0xFF},
	{0x18b00 & 0xFF, 0x18bff & 0xFF},
	{0x18c00 & 0xFF, 0x18cd5 & 0xFF},
	{0x18cff & 0xFF, 0x18cff & 0xFF},
	{0x18d00 & 0xFF, 0x18d08 & 0xFF},
	{0x1aff0 & 0xFF, 0x1aff3 & 0xFF},
	{0x1aff5 & 0xFF, 0x1affb & 0xFF},
	{0x1affd & 0xFF, 0x1affe & 0xFF},
	{0x1b000 & 0xFF, 0x1b000 & 0xFF},
	{0x1b001 & 0xFF, 0x1b0ff & 0xFF},
	{0x1b100 & 0xFF, 0x1b11f & 0xFF},
	{0x1b120 & 0xFF, 0x1b122 & 0xFF},
	{0x1b132 & 0xFF, 0x1b132 & 0xFF},
	{0x1b150 & 0xFF, 0x1b152 & 0xFF},
	{0x1b155 & 0xFF, 0x1b155 & 0xFF},
	{0x1b164 & 0xFF, 0x1b167 & 0xFF},
	{0x1b170 & 0xFF, 0x1b1ff & 0xFF},
	{0x1b200 & 0xFF, 0x1b2fb & 0xFF},
	{0x1bc00 & 0xFF, 0x1bc6a & 0xFF},
	{0x1bc70 & 0xFF, 0x1bc7c & 0xFF},
	{0x1bc80 & 0xFF, 0x1bc88 & 0xFF},
	{0x1bc90 & 0xFF, 0x1bc99 & 0xFF},
	{0x1bc9c & 0xFF, 0x1bc9f & 0xFF},
	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
	{0x1cc00 & 0xFF, 0x1ccf9 & 0xFF},
	{0x1cd00 & 0xFF, 0x1cdff & 0xFF},
	{0x1ce00 & 0xFF, 0x1ceb3 & 0xFF},
	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
	{0x1cf50 & 0xFF, 0x1cfc3 & 0xFF},
	{0x1d000 & 0xFF, 0x1d0f5 & 0xFF},
	{0x1d100 & 0xFF, 0x1d126 & 0xFF},
	{0x1d129 & 0xFF, 0x1d166 & 0xFF},
	{0x1d167 & 0xFF, 0x1d169 & 0xFF},
	{0x1d16a & 0xFF, 0x1d17a & 0xFF},
	{0x1d17b & 0xFF, 0x1d182 & 0xFF},
	{0x1d183 & 0xFF, 0x1d184 & 0xFF},
	{0x1d185 & 0xFF, 0x1d18b & 0xFF},
	{0x1d18c & 0xFF, 0x1d1a9 & 0xFF},
	{0x1d1aa & 0xFF, 0x1d1ad & 0xFF},
	{0x1d1ae & 0xFF, 0x1d1ea & 0xFF},
	{0x1d200 & 0xFF, 0x1d245 & 0xFF},
	{0x1d2c0 & 0xFF, 0x1d2d3 & 0xFF},
	{0x1d2e0 & 0xFF, 0x1d2f3 & 0xFF},
	{0x1d300 & 0xFF, 0x1d356 & 0xFF},
	{0x1d360 & 0xFF, 0x1d378 & 0xFF},
	{0x1d400 & 0xFF, 0x1d454 & 0xFF},
	{0x1d456 & 0xFF, 0x1d49c & 0xFF},
	{0x1d49e & 0xFF, 0x1d49f & 0xFF},
	{0x1d4a2 & 0xFF, 0x1d4a2 & 0xFF},
	{0x1d4a5 & 0xFF, 0x1d4a6 & 0xFF},
	{0x1d4a9 & 0xFF, 0x1d4ac & 0xFF},
	{0x1d4ae & 0xFF, 0x1d4b9 & 0xFF},
	{0x1d4bb & 0xFF, 0x1d4bb & 0xFF},
	{0x1d4bd & 0xFF, 0x1d4c3 & 0xFF},
	{0x1d4c5 & 0xFF, 0x1d4ff & 0xFF},
	{0x1d500 & 0xFF, 0x1d505 & 0xFF},
	{0x1d507 & 0xFF, 0x1d50a & 0xFF},
	{0x1d50d & 0xFF, 0x1d514 & 0xFF},
	{0x1d516 & 0xFF, 0x1d51c & 0xFF},
	{0x1d51e & 0xFF, 0x1d539 & 0xFF},
	{0x1d53b & 0xFF, 0x1d53e & 0xFF},
	{0x1d540 & 0xFF, 0x1d544 & 0xFF},
	{0x1d546 & 0xFF, 0x1d546 & 0xFF},
	{0x1d54a & 0xFF, 0x1d550 & 0xFF},
	{0x1d552 & 0xFF, 0x1d5ff & 0xFF},
	{0x1d600 & 0xFF, 0x1d6a5 & 0xFF},
	{0x1d6a8 & 0xFF, 0x1d6ff & 0xFF},
	{0x1d700 & 0xFF, 0x1d7cb & 0xFF},
	{0x1d7ce & 0xFF, 0x1d7ff & 0xFF},
	{0x1d800 & 0xFF, 0x1d8ff & 0xFF},
	{0x1d900 & 0xFF, 0x1d9ff & 0xFF},
	{0x1da00 & 0xFF, 0x1da8b & 0xFF},
	{0x1da9b & 0xFF, 0x1da9f & 0xFF},
	{0x1daa1 & 0xFF, 0x1daaf & 0xFF},
	{0x1df00 & 0xFF, 0x1df1e & 0xFF},
	{0x1df25 & 0xFF, 0x1df2a & 0xFF},
	{0x1e000 & 0xFF, 0x1e006 & 0xFF},
	{0x1e008 & 0xFF, 0x1e018 & 0xFF},
	{0x1e01b & 0xFF, 0x1e021 & 0xFF},
	{0x1e023 & 0xFF, 0x1e024 & 0xFF},
	{0x1e026 & 0xFF, 0x1e02a & 0xFF},
	{0x1e030 & 0xFF, 0x1e06d & 0xFF},
	{0x1e08f & 0xFF, 0x1e08f & 0xFF},
	{0x1e100 & 0xFF, 0x1e12c & 0xFF},
	{0x1e130 & 0xFF, 0x1e13d & 0xFF},
	{0x1e140 & 0xFF, 0x1e149 & 0xFF},
	{0x1e14e & 0xFF, 0x1e14f & 0xFF},
	{0x1e290 & 0xFF, 0x1e2ae & 0xFF},
	{0x1e2c0 & 0xFF, 0x1e2f9 & 0xFF},
	{0x1e2ff & 0xFF, 0x1e2ff & 0xFF},
	{0x1e4d0 & 0xFF, 0x1e4f9 & 0xFF},
	{0x1e5d0 & 0xFF, 0x1e5fa & 0xFF},
	{0x1e5ff & 0xFF, 0x1e5ff & 0xFF},
	{0x1e7e0 & 0xFF, 0x1e7e6 & 0xFF},
	{0x1e7e8 & 0xFF, 0x1e7eb & 0xFF},
	{0x1e7ed & 0xFF, 0x1e7ee & 0xFF},
	{0x1e7f0 & 0xFF, 0x1e7fe & 0xFF},
	{0x1e800 & 0xFF, 0x1e8c4 & 0xFF},
	{0x1e8c7 & 0xFF, 0x1e8d6 & 0xFF},
	{0x1e900 & 0xFF, 0x1e94b & 0xFF},
	{0x1e950 & 0xFF, 0x1e959 & 0xFF},
	{0x1e95e & 0xFF, 0x1e95f & 0xFF},
	{0x1ec71 & 0xFF, 0x1ecb4 & 0xFF},
	{0x1ed01 & 0xFF, 0x1ed3d & 0xFF},
	{0x1ee00 & 0xFF, 0x1ee03 & 0xFF},
	{0x1ee05 & 0xFF, 0x1ee1f & 0xFF},
	{0x1ee21 & 0xFF, 0x1ee22 & 0xFF},
	{0x1ee24 & 0xFF, 0x1ee24 & 0xFF},
	{0x1ee27 & 0xFF, 0x1ee27 & 0xFF},
	{0x1ee29 & 0xFF, 0x1ee32 & 0xFF},
	{0x1ee34 & 0xFF, 0x1ee37 & 0xFF},
	{0x1ee39 & 0xFF, 0x1ee39 & 0xFF},
	{0x1ee3b & 0xFF, 0x1ee3b & 0xFF},
	{0x1ee42 & 0xFF, 0x1ee42 & 0xFF},
	{0x1ee47 & 0xFF, 0x1ee47 & 0xFF},
	{0x1ee49 & 0xFF, 0x1ee49 & 0xFF},
	{0x1ee4b & 0xFF, 0x1ee4b & 0xFF},
	{0x1ee4d & 0xFF, 0x1ee4f & 0xFF},
	{0x1ee51 & 0xFF, 0x1ee52 & 0xFF},
	{0x1ee54 & 0xFF, 0x1ee54 & 0xFF},
	{0x1ee57 & 0xFF, 0x1ee57 & 0xFF},
	{0x1ee59 & 0xFF, 0x1ee59 & 0xFF},
	{0x1ee5b & 0xFF, 0x1ee5b & 0xFF},
	{0x1ee5d & 0xFF, 0x1ee5d & 0xFF},
	{0x1ee5f & 0xFF, 0x1ee5f & 0xFF},
	{0x1ee61 & 0xFF, 0x1ee62 & 0xFF},
	{0x1ee64 & 0xFF, 0x1ee64 & 0xFF},
	{0x1ee67 & 0xFF, 0x1ee6a & 0xFF},
	{0x1ee6c & 0xFF, 0x1ee72 & 0xFF},
	{0x1ee74 & 0xFF, 0x1ee77 & 0xFF},
	{0x1ee79 & 0xFF, 0x1ee7c & 0xFF},
	{0x1ee7e & 0xFF, 0x1ee7e & 0xFF},
	{0x1ee80 & 0xFF, 0x1ee89 & 0xFF},
	{0x1ee8b & 0xFF, 0x1ee9b & 0xFF},
	{0x1eea1 & 0xFF, 0x1eea3 & 0xFF},
	{0x1eea5 & 0xFF, 0x1eea9 & 0xFF},
	{0x1eeab & 0xFF, 0x1eebb & 0xFF},
	{0x1eef0 & 0xFF, 0x1eef1 & 0xFF},
	{0x1f000 & 0xFF, 0x1f02b & 0xFF},
	{0x1f030 & 0xFF, 0x1f093 & 0xFF},
	{0x1f0a0 & 0xFF, 0x1f0ae & 0xFF},
	{0x1f0b1 & 0xFF, 0x1f0bf & 0xFF},
	{0x1f0c1 & 0xFF, 0x1f0cf & 0xFF},
	{0x1f0d1 & 0xFF, 0x1f0f5 & 0xFF},
	{0x1f100 & 0xFF, 0x1f1ad & 0xFF},
	{0x1f1e6 & 0xFF, 0x1f1ff & 0xFF},
	{0x1f200 & 0xFF, 0x1f200 & 0xFF},
	{0x1f201 & 0xFF, 0x1f202 & 0xFF},
	{0x1f210 & 0xFF, 0x1f23b & 0xFF},
	{0x1f240 & 0xFF, 0x1f248 & 0xFF},
	{0x1f250 & 0xFF, 0x1f251 & 0xFF},
	{0x1f260 & 0xFF, 0x1f265 & 0xFF},
	{0x1f300 & 0xFF, 0x1f3ff & 0xFF},
	{0x1f400 & 0xFF, 0x1f4ff & 0xFF},
	{0x1f500 & 0xFF, 0x1f5ff & 0xFF},
	{0x1f600 & 0xFF, 0x1f6d7 & 0xFF},
	{0x1f6dc & 0xFF, 0x1f6ec & 0xFF},
	{0x1f6f0 & 0xFF, 0x1f6fc & 0xFF},
	{0x1f700 & 0xFF, 0x1f776 & 0xFF},
	{0x1f77b & 0xFF, 0x1f7d9 & 0xFF},
	{0x1f7e0 & 0xFF, 0x1f7eb & 0xFF},
	{0x1f7f0 & 0xFF, 0x1f7f0 & 0xFF},
	{0x1f800 & 0xFF, 0x1f80b & 0xFF},
	{0x1f810 & 0xFF, 0x1f847 & 0xFF},
	{0x1f850 & 0xFF, 0x1f859 & 0xFF},
	{0x1f860 & 0xFF, 0x1f887 & 0xFF},
	{0x1f890 & 0xFF, 0x1f8ad & 0xFF},
	{0x1f8b0 & 0xFF, 0x1f8bb & 0xFF},
	{0x1f8c0 & 0xFF, 0x1f8c1 & 0xFF},
	{0x1f900 & 0xFF, 0x1f9ff & 0xFF},
	{0x1fa00 & 0xFF, 0x1fa53 & 0xFF},
	{0x1fa60 & 0xFF, 0x1fa6d & 0xFF},
	{0x1fa70 & 0xFF, 0x1fa7c & 0xFF},
	{0x1fa80 & 0xFF, 0x1fa89 & 0xFF},
	{0x1fa8f & 0xFF, 0x1fac6 & 0xFF},
	{0x1face & 0xFF, 0x1fadc & 0xFF},
	{0x1fadf & 0xFF, 0x1fae9 & 0xFF},
	{0x1faf0 & 0xFF, 0x1faf8 & 0xFF},
	{0x1fb00 & 0xFF, 0x1fb92 & 0xFF},
	{0x1fb94 & 0xFF, 0x1fbf9 & 0xFF},
	{0x20000 & 0xFF, 0x200ff & 0xFF},
	{0x20100 & 0xFF, 0x201ff & 0xFF},
	{0x20200 & 0xFF, 0x202ff & 0xFF},
	{0x20300 & 0xFF, 0x203ff & 0xFF},
	{0x20400 & 0xFF, 0x204ff & 0xFF},
	{0x20500 & 0xFF, 0x205ff & 0xFF},
	{0x20600 & 0xFF, 0x206ff & 0xFF},
	{0x20700 & 0xFF, 0x207ff & 0xFF},
	{0x20800 & 0xFF, 0x208ff & 0xFF},
	{0x20900 & 0xFF, 0x209ff & 0xFF},
	{0x20a00 & 0xFF, 0x20aff & 0xFF},
	{0x20b00 & 0xFF, 0x20bff & 0xFF},
	{0x20c00 & 0xFF, 0x20cff & 0xFF},
	{0x20d00 & 0xFF, 0x20dff & 0xFF},
	{0x20e00 & 0xFF, 0x20eff & 0xFF},
	{0x20f00 & 0xFF, 0x20fff & 0xFF},
	{0x21000 & 0xFF, 0x210ff & 0xFF},
	{0x21100 & 0xFF, 0x211ff & 0xFF},
	{0x21200 & 0xFF, 0x212ff & 0xFF},
	{0x21300 & 0xFF, 0x213ff & 0xFF},
	{0x21400 & 0xFF, 0x214ff & 0xFF},
	{0x21500 & 0xFF, 0x215ff & 0xFF},
	{0x21600 & 0xFF, 0x216ff & 0xFF},
	{0x21700 & 0xFF, 0x217ff & 0xFF},
	{0x21800 & 0xFF, 0x218ff & 0xFF},
	{0x21900 & 0xFF, 0x219ff & 0xFF},
	{0x21a00 & 0xFF, 0x21aff & 0xFF},
	{0x21b00 & 0xFF, 0x21bff & 0xFF},
	{0x21c00 & 0xFF, 0x21cff & 0xFF},
	{0x21d00 & 0xFF, 0x21dff & 0xFF},
	{0x21e00 & 0xFF, 0x21eff & 0xFF},
	{0x21f00 & 0xFF, 0x21fff & 0xFF},
	{0x22000 & 0xFF, 0x220ff & 0xFF},
	{0x22100 & 0xFF, 0x221ff & 0xFF},
	{0x22200 & 0xFF, 0x222ff & 0xFF},
	{0x22300 & 0xFF, 0x223ff & 0xFF},
	{0x22400 & 0xFF, 0x224ff & 0xFF},
	{0x22500 & 0xFF, 0x225ff & 0xFF},
	{0x22600 & 0xFF, 0x226ff & 0xFF},
	{0x22700 & 0xFF, 0x227ff & 0xFF},
	{0x22800 & 0xFF, 0x228ff & 0xFF},
	{0x22900 & 0xFF, 0x229ff & 0xFF},
	{0x22a00 & 0xFF, 0x22aff & 0xFF},
	{0x22b00 & 0xFF, 0x22bff & 0xFF},
	{0x22c00 & 0xFF, 0x22cff & 0xFF},
	{0x22d00 & 0xFF, 0x22dff & 0xFF},
	{0x22e00 & 0xFF, 0x22eff & 0xFF},
	{0x22f00 & 0xFF, 0x22fff & 0xFF},
	{0x23000 & 0xFF, 0x230ff & 0xFF},
	{0x23100 & 0xFF, 0x231ff & 0xFF},
	{0x23200 & 0xFF, 0x232ff & 0xFF},
	{0x23300 & 0xFF, 0x233ff & 0xFF},
	{0x23400 & 0xFF, 0x234ff & 0xFF},
	{0x23500 & 0xFF, 0x235ff & 0xFF},
	{0x23600 & 0xFF, 0x236ff & 0xFF},
	{0x23700 & 0xFF, 0x237ff & 0xFF},
	{0x23800 & 0xFF, 0x238ff & 0xFF},
	{0x23900 & 0xFF, 0x239ff & 0xFF},
	{0x23a00 & 0xFF, 0x23aff & 0xFF},
	{0x23b00 & 0xFF, 0x23bff & 0xFF},
	{0x23c00 & 0xFF, 0x23cff & 0xFF},
	{0x23d00 & 0xFF, 0x23dff & 0xFF},
	{0x23e00 & 0xFF, 0x23eff & 0xFF},
	{0x23f00 & 0xFF, 0x23fff & 0xFF},
	{0x24000 & 0xFF, 0x240ff & 0xFF},
	{0x24100 & 0xFF, 0x241ff & 0xFF},
	{0x24200 & 0xFF, 0x242ff & 0xFF},
	{0x24300 & 0xFF, 0x243ff & 0xFF},
	{0x24400 & 0xFF, 0x244ff & 0xFF},
	{0x24500 & 0xFF, 0x245ff & 0xFF},
	{0x24600 & 0xFF, 0x246ff & 0xFF},
	{0x24700 & 0xFF, 0x247ff & 0xFF},
	{0x24800 & 0xFF, 0x248ff & 0xFF},
	{0x24900 & 0xFF, 0x249ff & 0xFF},
	{0x24a00 & 0xFF, 0x24aff & 0xFF},
	{0x24b00 & 0xFF, 0x24bff & 0xFF},
	{0x24c00 & 0xFF, 0x24cff & 0xFF},
	{0x24d00 & 0xFF, 0x24dff & 0xFF},
	{0x24e00 & 0xFF, 0x24eff & 0xFF},
	{0x24f00 & 0xFF, 0x24fff & 0xFF},
	{0x25000 & 0xFF, 0x250ff & 0xFF},
	{0x25100 & 0xFF, 0x251ff & 0xFF},
	{0x25200 & 0xFF, 0x252ff & 0xFF},
	{0x25300 & 0xFF, 0x253ff & 0xFF},
	{0x25400 & 0xFF, 0x254ff & 0xFF},
	{0x25500 & 0xFF, 0x255ff & 0xFF},
	{0x25600 & 0xFF, 0x256ff & 0xFF},
	{0x25700 & 0xFF, 0x257ff & 0xFF},
	{0x25800 & 0xFF, 0x258ff & 0xFF},
	{0x25900 & 0xFF, 0x259ff & 0xFF},
	{0x25a00 & 0xFF, 0x25aff & 0xFF},
	{0x25b00 & 0xFF, 0x25bff & 0xFF},
	{0x25c00 & 0xFF, 0x25cff & 0xFF},
	{0x25d00 & 0xFF, 0x25dff & 0xFF},
	{0x25e00 & 0xFF, 0x25eff & 0xFF},
	{0x25f00 & 0xFF, 0x25fff & 0xFF},
	{0x26000 & 0xFF, 0x260ff & 0xFF},
	{0x26100 & 0xFF, 0x261ff & 0xFF},
	{0x26200 & 0xFF, 0x262ff & 0xFF},
	{0x26300 & 0xFF, 0x263ff & 0xFF},
	{0x26400 & 0xFF, 0x264ff & 0xFF},
	{0x26500 & 0xFF, 0x265ff & 0xFF},
	{0x26600 & 0xFF, 0x266ff & 0xFF},
	{0x26700 & 0xFF, 0x267ff & 0xFF},
	{0x26800 & 0xFF, 0x268ff & 0xFF},
	{0x26900 & 0xFF, 0x269ff & 0xFF},
	{0x26a00 & 0xFF, 0x26aff & 0xFF},
	{0x26b00 & 0xFF, 0x26bff & 0xFF},
	{0x26c00 & 0xFF, 0x26cff & 0xFF},
	{0x26d00 & 0xFF, 0x26dff & 0xFF},
	{0x26e00 & 0xFF, 0x26eff & 0xFF},
	{0x26f00 & 0xFF, 0x26fff & 0xFF},
	{0x27000 & 0xFF, 0x270ff & 0xFF},
	{0x27100 & 0xFF, 0x271ff & 0xFF},
	{0x27200 & 0xFF, 0x272ff & 0xFF},
	{0x27300 & 0xFF, 0x273ff & 0xFF},
	{0x27400 & 0xFF, 0x274ff & 0xFF},
	{0x27500 & 0xFF, 0x275ff & 0xFF},
	{0x27600 & 0xFF, 0x276ff & 0xFF},
	{0x27700 & 0xFF, 0x277ff & 0xFF},
	{0x27800 & 0xFF, 0x278ff & 0xFF},
	{0x27900 & 0xFF, 0x279ff & 0xFF},
	{0x27a00 & 0xFF, 0x27aff & 0xFF},
	{0x27b00 & 0xFF, 0x27bff & 0xFF},
	{0x27c00 & 0xFF, 0x27cff & 0xFF},
	{0x27d00 & 0xFF, 0x27dff & 0xFF},
	{0x27e00 & 0xFF, 0x27eff & 0xFF},
	{0x27f00 & 0xFF, 0x27fff & 0xFF},
	{0x28000 & 0xFF, 0x280ff & 0xFF},
	{0x28100 & 0xFF, 0x281ff & 0xFF},
	{0x28200 & 0xFF, 0x282ff & 0xFF},
	{0x28300 & 0xFF, 0x283ff & 0xFF},
	{0x28400 & 0xFF, 0x284ff & 0xFF},
	{0x28500 & 0xFF, 0x285ff & 0xFF},
	{0x28600 & 0xFF, 0x286ff & 0xFF},
	{0x28700 & 0xFF, 0x287ff & 0xFF},
	{0x28800 & 0xFF, 0x288ff & 0xFF},
	{0x28900 & 0xFF, 0x289ff & 0xFF},
	{0x28a00 & 0xFF, 0x28aff & 0xFF},
	{0x28b00 & 0xFF, 0x28bff & 0xFF},
	{0x28c00 & 0xFF, 0x28cff & 0xFF},
	{0x28d00 & 0xFF, 0x28dff & 0xFF},
	{0x28e00 & 0xFF, 0x28eff & 0xFF},
	{0x28f00 & 0xFF, 0x28fff & 0xFF},
	{0x29000 & 0xFF, 0x290ff & 0xFF},
	{0x29100 & 0xFF, 0x291ff & 0xFF},
	{0x29200 & 0xFF, 0x292ff & 0xFF},
	{0x29300 & 0xFF, 0x293ff & 0xFF},
	{0x29400 & 0xFF, 0x294ff & 0xFF},
	{0x29500 & 0xFF, 0x295ff & 0xFF},
	{0x29600 & 0xFF, 0x296ff & 0xFF},
	{0x29700 & 0xFF, 0x297ff & 0xFF},
	{0x29800 & 0xFF, 0x298ff & 0xFF},
	{0x29900 & 0xFF, 0x299ff & 0xFF},
	{0x29a00 & 0xFF, 0x29aff & 0xFF},
	{0x29b00 & 0xFF, 0x29bff & 0xFF},
	{0x29c00 & 0xFF, 0x29cff & 0xFF},
	{0x29d00 & 0xFF, 0x29dff & 0xFF},
	{0x29e00 & 0xFF, 0x29eff & 0xFF},
	{0x29f00 & 0xFF, 0x29fff & 0xFF},
	{0x2a000 & 0xFF, 0x2a0ff & 0xFF},
	{0x2a100 & 0xFF, 0x2a1ff & 0xFF},
	{0x2a200 & 0xFF, 0x2a2ff & 0xFF},
	{0x2a300 & 0xFF, 0x2a3ff & 0xFF},
	{0x2a400 & 0xFF, 0x2a4ff & 0xFF},
	{0x2a500 & 0xFF, 0x2a5ff & 0xFF},
	{0x2a600 & 0xFF, 0x2a6df & 0xFF},
	{0x2a700 & 0xFF, 0x2a7ff & 0xFF},
	{0x2a800 & 0xFF, 0x2a8ff & 0xFF},
	{0x2a900 & 0xFF, 0x2a9ff & 0xFF},
	{0x2aa00 & 0xFF, 0x2aaff & 0xFF},
	{0x2ab00 & 0xFF, 0x2abff & 0xFF},
	{0x2ac00 & 0xFF, 0x2acff & 0xFF},
	{0x2ad00 & 0xFF, 0x2adff & 0xFF},
	{0x2ae00 & 0xFF, 0x2aeff & 0xFF},
	{0x2af00 & 0xFF, 0x2afff & 0xFF},
	{0x2b000 & 0xFF, 0x2b0ff & 0xFF},
	{0x2b100 & 0xFF, 0x2b1ff & 0xFF},
	{0x2b200 & 0xFF, 0x2b2ff & 0xFF},
	{0x2b300 & 0xFF, 0x2b3ff & 0xFF},
	{0x2b400 & 0xFF, 0x2b4ff & 0xFF},
	{0x2b500 & 0xFF, 0x2b5ff & 0xFF},
	{0x2b600 & 0xFF, 0x2b6ff & 0xFF},
	{0x2b700 & 0xFF, 0x2b739 & 0xFF},
	{0x2b740 & 0xFF, 0x2b7ff & 0xFF},
	{0x2b800 & 0xFF, 0x2b81d & 0xFF},
	{0x2b820 & 0xFF, 0x2b8ff & 0xFF},
	{0x2b900 & 0xFF, 0x2b9ff & 0xFF},
	{0x2ba00 & 0xFF, 0x2baff & 0xFF},
	{0x2bb00 & 0xFF, 0x2bbff & 0xFF},
	{0x2bc00 & 0xFF, 0x2bcff & 0xFF},
	{0x2bd00 & 0xFF, 0x2bdff & 0xFF},
	{0x2be00 & 0xFF, 0x2beff & 0xFF},
	{0x2bf00 & 0xFF, 0x2bfff & 0xFF},
	{0x2c000 & 0xFF, 0x2c0ff & 0xFF},
	{0x2c100 & 0xFF, 0x2c1ff & 0xFF},
	{0x2c200 & 0xFF, 0x2c2ff & 0xFF},
	{0x2c300 & 0xFF, 0x2c3ff & 0xFF},
	{0x2c400 & 0xFF, 0x2c4ff & 0xFF},
	{0x2c500 & 0xFF, 0x2c5ff & 0xFF},
	{0x2c600 & 0xFF, 0x2c6ff & 0xFF},
	{0x2c700 & 0xFF, 0x2c7ff & 0xFF},
	{0x2c800 & 0xFF, 0x2c8ff & 0xFF},
	{0x2c900 & 0xFF, 0x2c9ff & 0xFF},
	{0x2ca00 & 0xFF, 0x2caff & 0xFF},
	{0x2cb00 & 0xFF, 0x2cbff & 0xFF},
	{0x2cc00 & 0xFF, 0x2ccff & 0xFF},
	{0x2cd00 & 0xFF, 0x2cdff & 0xFF},
	{0x2ce00 & 0xFF, 0x2cea1 & 0xFF},
	{0x2ceb0 & 0xFF, 0x2ceff & 0xFF},
	{0x2cf00 & 0xFF, 0x2cfff & 0xFF},
	{0x2d000 & 0xFF, 0x2d0ff & 0xFF},
	{0x2d100 & 0xFF, 0x2d1ff & 0xFF},
	{0x2d200 & 0xFF, 0x2d2ff & 0xFF},
	{0x2d300 & 0xFF, 0x2d3ff & 0xFF},
	{0x2d400 & 0xFF, 0x2d4ff & 0xFF},
	{0x2d500 & 0xFF, 0x2d5ff & 0xFF},
	{0x2d600 & 0xFF, 0x2d6ff & 0xFF},
	{0x2d700 & 0xFF, 0x2d7ff & 0xFF},
	{0x2d800 & 0xFF, 0x2d8ff & 0xFF},
	{0x2d900 & 0xFF, 0x2d9ff & 0xFF},
	{0x2da00 & 0xFF, 0x2daff & 0xFF},
	{0x2db00 & 0xFF, 0x2dbff & 0xFF},
	{0x2dc00 & 0xFF, 0x2dcff & 0xFF},
	{0x2dd00 & 0xFF, 0x2ddff & 0xFF},
	{0x2de00 & 0xFF, 0x2deff & 0xFF},
	{0x2df00 & 0xFF, 0x2dfff & 0xFF},
	{0x2e000 & 0xFF, 0x2e0ff & 0xFF},
	{0x2e100 & 0xFF, 0x2e1ff & 0xFF},
	{0x2e200 & 0xFF, 0x2e2ff & 0xFF},
	{0x2e300 & 0xFF, 0x2e3ff & 0xFF},
	{0x2e400 & 0xFF, 0x2e4ff & 0xFF},
	{0x2e500 & 0xFF, 0x2e5ff & 0xFF},
	{0x2e600 & 0xFF, 0x2e6ff & 0xFF},
	{0x2e700 & 0xFF, 0x2e7ff & 0xFF},
	{0x2e800 & 0xFF, 0x2e8ff & 0xFF},
	{0x2e900 & 0xFF, 0x2e9ff & 0xFF},
	{0x2ea00 & 0xFF, 0x2eaff & 0xFF},
	{0x2eb00 & 0xFF, 0x2ebe0 & 0xFF},
	{0x2ebf0 & 0xFF, 0x2ebff & 0xFF},
	{0x2ec00 & 0xFF, 0x2ecff & 0xFF},
	{0x2ed00 & 0xFF, 0x2edff & 0xFF},
	{0x2ee00 & 0xFF, 0x2ee5d & 0xFF},
	{0x2f800 & 0xFF, 0x2f8ff & 0xFF},
	{0x2f900 & 0xFF, 0x2f9ff & 0xFF},
	{0x2fa00 & 0xFF, 0x2fa1d & 0xFF},
	{0x30000 & 0xFF, 0x300ff & 0xFF},
	{0x30100 & 0xFF, 0x301ff & 0xFF},
	{0x30200 & 0xFF, 0x302ff & 0xFF},
	{0x30300 & 0xFF, 0x303ff & 0xFF},
	{0x30400 & 0xFF, 0x304ff & 0xFF},
	{0x30500 & 0xFF, 0x305ff & 0xFF},
	{0x30600 & 0xFF, 0x306ff & 0xFF},
	{0x30700 & 0xFF, 0x307ff & 0xFF},
	{0x30800 & 0xFF, 0x308ff & 0xFF},
	{0x30900 & 0xFF, 0x309ff & 0xFF},
	{0x30a00 & 0xFF, 0x30aff & 0xFF},
	{0x30b00 & 0xFF, 0x30bff & 0xFF},
	{0x30c00 & 0xFF, 0x30cff & 0xFF},
	{0x30d00 & 0xFF, 0x30dff & 0xFF},
	{0x30e00 & 0xFF, 0x30eff & 0xFF},
	{0x30f00 & 0xFF, 0x30fff & 0xFF},
	{0x31000 & 0xFF, 0x310ff & 0xFF},
	{0x31100 & 0xFF, 0x311ff & 0xFF},
	{0x31200 & 0xFF, 0x312ff & 0xFF},
	{0x31300 & 0xFF, 0x3134a & 0xFF},
	{0x31350 & 0xFF, 0x313ff & 0xFF},
	{0x31400 & 0xFF, 0x314ff & 0xFF},
	{0x31500 & 0xFF, 0x315ff & 0xFF},
	{0x31600 & 0xFF, 0x316ff & 0xFF},
	{0x31700 & 0xFF, 0x317ff & 0xFF},
	{0x31800 & 0xFF, 0x318ff & 0xFF},
	{0x31900 & 0xFF, 0x319ff & 0xFF},
	{0x31a00 & 0xFF, 0x31aff & 0xFF},
	{0x31b00 & 0xFF, 0x31bff & 0xFF},
	{0x31c00 & 0xFF, 0x31cff & 0xFF},
	{0x31d00 & 0xFF, 0x31dff & 0xFF},
	{0x31e00 & 0xFF, 0x31eff & 0xFF},
	{0x31f00 & 0xFF, 0x31fff & 0xFF},
	{0x32000 & 0xFF, 0x320ff & 0xFF},
	{0x32100 & 0xFF, 0x321ff & 0xFF},
	{0x32200 & 0xFF, 0x322ff & 0xFF},
	{0x32300 & 0xFF, 0x323af & 0xFF},
	{0xe0001 & 0xFF, 0xe0001 & 0xFF},
	{0xe0020 & 0xFF, 0xe007f & 0xFF},
	{0xe0100 & 0xFF, 0xe01ef & 0xFF}};

static const uint8_t unicode_classtab[]={
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_bopomofo,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_coptic,
	unicode_script_greek,
	unicode_script_cyrillic,
	unicode_script_inherited,
	unicode_script_cyrillic,
	unicode_script_cyrillic,
	unicode_script_armenian,
	unicode_script_armenian,
	unicode_script_armenian,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_inherited,
	unicode_script_arabic,
	unicode_script_inherited,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_syriac,
	unicode_script_syriac,
	unicode_script_syriac,
	unicode_script_arabic,
	unicode_script_thaana,
	unicode_script_nko,
	unicode_script_nko,
	unicode_script_samaritan,
	unicode_script_samaritan,
	unicode_script_mandaic,
	unicode_script_mandaic,
	unicode_script_syriac,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_devanagari,
	unicode_script_inherited,
	unicode_script_devanagari,
	unicode_script_common,
	unicode_script_devanagari,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_bengali,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gurmukhi,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_gujarati,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_oriya,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_telugu,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_kannada,
	unicode_script_malayalam,
	unicode_script_malayalam,
	unicode_script_malayalam,
	unicode_script_malayalam,
	unicode_script_malayalam,
	unicode_script_malayalam,
	unicode_script_malayalam,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_sinhala,
	unicode_script_thai,
	unicode_script_common,
	unicode_script_thai,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_lao,
	unicode_script_tibetan,
	unicode_script_tibetan,
	unicode_script_tibetan,
	unicode_script_tibetan,
	unicode_script_tibetan,
	unicode_script_tibetan,
	unicode_script_common,
	unicode_script_tibetan,
	unicode_script_myanmar,
	unicode_script_georgian,
	unicode_script_georgian,
	unicode_script_georgian,
	unicode_script_georgian,
	unicode_script_common,
	unicode_script_georgian,
	unicode_script_hangul,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_cherokee,
	unicode_script_cherokee,
	unicode_script_canadian_aboriginal,
	unicode_script_canadian_aboriginal,
	unicode_script_canadian_aboriginal,
	unicode_script_ogham,
	unicode_script_runic,
	unicode_script_common,
	unicode_script_runic,
	unicode_script_tagalog,
	unicode_script_tagalog,
	unicode_script_hanunoo,
	unicode_script_common,
	unicode_script_buhid,
	unicode_script_tagbanwa,
	unicode_script_tagbanwa,
	unicode_script_tagbanwa,
	unicode_script_khmer,
	unicode_script_khmer,
	unicode_script_khmer,
	unicode_script_mongolian,
	unicode_script_common,
	unicode_script_mongolian,
	unicode_script_common,
	unicode_script_mongolian,
	unicode_script_mongolian,
	unicode_script_mongolian,
	unicode_script_canadian_aboriginal,
	unicode_script_limbu,
	unicode_script_limbu,
	unicode_script_limbu,
	unicode_script_limbu,
	unicode_script_limbu,
	unicode_script_tai_le,
	unicode_script_tai_le,
	unicode_script_new_tai_lue,
	unicode_script_new_tai_lue,
	unicode_script_new_tai_lue,
	unicode_script_new_tai_lue,
	unicode_script_khmer,
	unicode_script_buginese,
	unicode_script_buginese,
	unicode_script_tai_tham,
	unicode_script_tai_tham,
	unicode_script_tai_tham,
	unicode_script_tai_tham,
	unicode_script_tai_tham,
	unicode_script_inherited,
	unicode_script_balinese,
	unicode_script_balinese,
	unicode_script_sundanese,
	unicode_script_batak,
	unicode_script_batak,
	unicode_script_lepcha,
	unicode_script_lepcha,
	unicode_script_lepcha,
	unicode_script_ol_chiki,
	unicode_script_cyrillic,
	unicode_script_georgian,
	unicode_script_georgian,
	unicode_script_sundanese,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_greek,
	unicode_script_cyrillic,
	unicode_script_latin,
	unicode_script_greek,
	unicode_script_latin,
	unicode_script_greek,
	unicode_script_latin,
	unicode_script_cyrillic,
	unicode_script_latin,
	unicode_script_greek,
	unicode_script_inherited,
	unicode_script_latin,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_braille,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_glagolitic,
	unicode_script_latin,
	unicode_script_coptic,
	unicode_script_coptic,
	unicode_script_georgian,
	unicode_script_georgian,
	unicode_script_georgian,
	unicode_script_tifinagh,
	unicode_script_tifinagh,
	unicode_script_tifinagh,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_cyrillic,
	unicode_script_common,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_common,
	unicode_script_common,
	unicode_script_han,
	unicode_script_common,
	unicode_script_han,
	unicode_script_common,
	unicode_script_han,
	unicode_script_inherited,
	unicode_script_hangul,
	unicode_script_common,
	unicode_script_han,
	unicode_script_common,
	unicode_script_hiragana,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_hiragana,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_bopomofo,
	unicode_script_hangul,
	unicode_script_common,
	unicode_script_bopomofo,
	unicode_script_common,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_hangul,
	unicode_script_common,
	unicode_script_hangul,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_common,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_common,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_yi,
	unicode_script_yi,
	unicode_script_yi,
	unicode_script_yi,
	unicode_script_yi,
	unicode_script_yi,
	unicode_script_lisu,
	unicode_script_vai,
	unicode_script_vai,
	unicode_script_cyrillic,
	unicode_script_bamum,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_syloti_nagri,
	unicode_script_common,
	unicode_script_phags_pa,
	unicode_script_saurashtra,
	unicode_script_saurashtra,
	unicode_script_devanagari,
	unicode_script_kayah_li,
	unicode_script_common,
	unicode_script_kayah_li,
	unicode_script_rejang,
	unicode_script_rejang,
	unicode_script_hangul,
	unicode_script_javanese,
	unicode_script_common,
	unicode_script_javanese,
	unicode_script_javanese,
	unicode_script_myanmar,
	unicode_script_cham,
	unicode_script_cham,
	unicode_script_cham,
	unicode_script_cham,
	unicode_script_myanmar,
	unicode_script_tai_viet,
	unicode_script_tai_viet,
	unicode_script_meetei_mayek,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_greek,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_cherokee,
	unicode_script_meetei_mayek,
	unicode_script_meetei_mayek,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_latin,
	unicode_script_armenian,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_hebrew,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_cyrillic,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_latin,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_common,
	unicode_script_katakana,
	unicode_script_common,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_hangul,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_linear_b,
	unicode_script_linear_b,
	unicode_script_linear_b,
	unicode_script_linear_b,
	unicode_script_linear_b,
	unicode_script_linear_b,
	unicode_script_linear_b,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_lycian,
	unicode_script_carian,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_old_italic,
	unicode_script_old_italic,
	unicode_script_gothic,
	unicode_script_old_permic,
	unicode_script_ugaritic,
	unicode_script_ugaritic,
	unicode_script_old_persian,
	unicode_script_old_persian,
	unicode_script_deseret,
	unicode_script_shavian,
	unicode_script_osmanya,
	unicode_script_osmanya,
	unicode_script_osage,
	unicode_script_osage,
	unicode_script_elbasan,
	unicode_script_caucasian_albanian,
	unicode_script_caucasian_albanian,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_vithkuqi,
	unicode_script_todhri,
	unicode_script_linear_a,
	unicode_script_linear_a,
	unicode_script_linear_a,
	unicode_script_linear_a,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_cypriot,
	unicode_script_cypriot,
	unicode_script_cypriot,
	unicode_script_cypriot,
	unicode_script_cypriot,
	unicode_script_cypriot,
	unicode_script_imperial_aramaic,
	unicode_script_imperial_aramaic,
	unicode_script_palmyrene,
	unicode_script_nabataean,
	unicode_script_nabataean,
	unicode_script_hatran,
	unicode_script_hatran,
	unicode_script_hatran,
	unicode_script_phoenician,
	unicode_script_phoenician,
	unicode_script_lydian,
	unicode_script_lydian,
	unicode_script_meroitic_hieroglyphs,
	unicode_script_meroitic_cursive,
	unicode_script_meroitic_cursive,
	unicode_script_meroitic_cursive,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_kharoshthi,
	unicode_script_old_south_arabian,
	unicode_script_old_north_arabian,
	unicode_script_manichaean,
	unicode_script_manichaean,
	unicode_script_avestan,
	unicode_script_avestan,
	unicode_script_inscriptional_parthian,
	unicode_script_inscriptional_parthian,
	unicode_script_inscriptional_pahlavi,
	unicode_script_inscriptional_pahlavi,
	unicode_script_psalter_pahlavi,
	unicode_script_psalter_pahlavi,
	unicode_script_psalter_pahlavi,
	unicode_script_old_turkic,
	unicode_script_old_hungarian,
	unicode_script_old_hungarian,
	unicode_script_old_hungarian,
	unicode_script_hanifi_rohingya,
	unicode_script_hanifi_rohingya,
	unicode_script_garay,
	unicode_script_garay,
	unicode_script_garay,
	unicode_script_arabic,
	unicode_script_yezidi,
	unicode_script_yezidi,
	unicode_script_yezidi,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_old_sogdian,
	unicode_script_sogdian,
	unicode_script_old_uyghur,
	unicode_script_chorasmian,
	unicode_script_elymaic,
	unicode_script_brahmi,
	unicode_script_brahmi,
	unicode_script_brahmi,
	unicode_script_kaithi,
	unicode_script_kaithi,
	unicode_script_sora_sompeng,
	unicode_script_sora_sompeng,
	unicode_script_chakma,
	unicode_script_chakma,
	unicode_script_mahajani,
	unicode_script_sharada,
	unicode_script_sinhala,
	unicode_script_khojki,
	unicode_script_khojki,
	unicode_script_multani,
	unicode_script_multani,
	unicode_script_multani,
	unicode_script_multani,
	unicode_script_multani,
	unicode_script_khudawadi,
	unicode_script_khudawadi,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_inherited,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_grantha,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_tulu_tigalari,
	unicode_script_newa,
	unicode_script_newa,
	unicode_script_tirhuta,
	unicode_script_tirhuta,
	unicode_script_siddham,
	unicode_script_siddham,
	unicode_script_modi,
	unicode_script_modi,
	unicode_script_mongolian,
	unicode_script_takri,
	unicode_script_takri,
	unicode_script_myanmar,
	unicode_script_ahom,
	unicode_script_ahom,
	unicode_script_ahom,
	unicode_script_dogra,
	unicode_script_warang_citi,
	unicode_script_warang_citi,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_dives_akuru,
	unicode_script_nandinagari,
	unicode_script_nandinagari,
	unicode_script_nandinagari,
	unicode_script_zanabazar_square,
	unicode_script_soyombo,
	unicode_script_canadian_aboriginal,
	unicode_script_pau_cin_hau,
	unicode_script_devanagari,
	unicode_script_sunuwar,
	unicode_script_sunuwar,
	unicode_script_bhaiksuki,
	unicode_script_bhaiksuki,
	unicode_script_bhaiksuki,
	unicode_script_bhaiksuki,
	unicode_script_marchen,
	unicode_script_marchen,
	unicode_script_marchen,
	unicode_script_masaram_gondi,
	unicode_script_masaram_gondi,
	unicode_script_masaram_gondi,
	unicode_script_masaram_gondi,
	unicode_script_masaram_gondi,
	unicode_script_masaram_gondi,
	unicode_script_masaram_gondi,
	unicode_script_gunjala_gondi,
	unicode_script_gunjala_gondi,
	unicode_script_gunjala_gondi,
	unicode_script_gunjala_gondi,
	unicode_script_gunjala_gondi,
	unicode_script_gunjala_gondi,
	unicode_script_makasar,
	unicode_script_kawi,
	unicode_script_kawi,
	unicode_script_kawi,
	unicode_script_lisu,
	unicode_script_tamil,
	unicode_script_tamil,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cuneiform,
	unicode_script_cypro_minoan,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_egyptian_hieroglyphs,
	unicode_script_anatolian_hieroglyphs,
	unicode_script_anatolian_hieroglyphs,
	unicode_script_anatolian_hieroglyphs,
	unicode_script_gurung_khema,
	unicode_script_bamum,
	unicode_script_bamum,
	unicode_script_bamum,
	unicode_script_mro,
	unicode_script_mro,
	unicode_script_mro,
	unicode_script_tangsa,
	unicode_script_tangsa,
	unicode_script_bassa_vah,
	unicode_script_bassa_vah,
	unicode_script_pahawh_hmong,
	unicode_script_pahawh_hmong,
	unicode_script_pahawh_hmong,
	unicode_script_pahawh_hmong,
	unicode_script_pahawh_hmong,
	unicode_script_kirat_rai,
	unicode_script_medefaidrin,
	unicode_script_miao,
	unicode_script_miao,
	unicode_script_miao,
	unicode_script_tangut,
	unicode_script_nushu,
	unicode_script_han,
	unicode_script_khitan_small_script,
	unicode_script_han,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_tangut,
	unicode_script_khitan_small_script,
	unicode_script_khitan_small_script,
	unicode_script_khitan_small_script,
	unicode_script_tangut,
	unicode_script_katakana,
	unicode_script_katakana,
	unicode_script_katakana,
	unicode_script_katakana,
	unicode_script_hiragana,
	unicode_script_hiragana,
	unicode_script_katakana,
	unicode_script_hiragana,
	unicode_script_hiragana,
	unicode_script_katakana,
	unicode_script_katakana,
	unicode_script_nushu,
	unicode_script_nushu,
	unicode_script_duployan,
	unicode_script_duployan,
	unicode_script_duployan,
	unicode_script_duployan,
	unicode_script_duployan,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_inherited,
	unicode_script_common,
	unicode_script_greek,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_signwriting,
	unicode_script_signwriting,
	unicode_script_signwriting,
	unicode_script_signwriting,
	unicode_script_signwriting,
	unicode_script_latin,
	unicode_script_latin,
	unicode_script_glagolitic,
	unicode_script_glagolitic,
	unicode_script_glagolitic,
	unicode_script_glagolitic,
	unicode_script_glagolitic,
	unicode_script_cyrillic,
	unicode_script_cyrillic,
	unicode_script_nyiakeng_puachue_hmong,
	unicode_script_nyiakeng_puachue_hmong,
	unicode_script_nyiakeng_puachue_hmong,
	unicode_script_nyiakeng_puachue_hmong,
	unicode_script_toto,
	unicode_script_wancho,
	unicode_script_wancho,
	unicode_script_nag_mundari,
	unicode_script_ol_onal,
	unicode_script_ol_onal,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_ethiopic,
	unicode_script_mende_kikakui,
	unicode_script_mende_kikakui,
	unicode_script_adlam,
	unicode_script_adlam,
	unicode_script_adlam,
	unicode_script_common,
	unicode_script_common,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_arabic,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_hiragana,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_common,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_han,
	unicode_script_common,
	unicode_script_common,
	unicode_script_inherited};

static const size_t unicode_starting_indextab[]={
	0,
	1,
	2,
	3,
	4,
	5,
	6,
	7,
	8,
	9,
	10,
	11,
	12,
	13,
	14,
	15,
	16,
	17,
	18,
	19,
	20,
	21,
	22,
	23,
	24,
	25,
	26,
	27,
	28,
	29,
	30,
	31,
	32,
	33,
	34,
	35,
	36,
	37,
	38,
	39,
	40,
	41,
	42,
	43,
	44,
	45,
	46,
	47,
	48,
	49,
	50,
	51,
	52,
	53,
	54,
	55,
	56,
	57,
	58,
	59,
	60,
	61,
	62,
	63,
	64,
	65,
	66,
	67,
	68,
	69,
	70,
	71,
	72,
	73,
	74,
	75,
	76,
	77,
	78,
	79,
	80,
	81,
	82,
	83,
	84,
	85,
	86,
	87,
	88,
	89,
	90,
	91,
	92,
	93,
	94,
	95,
	96,
	97,
	98,
	99,
	100,
	101,
	102,
	103,
	104,
	105,
	106,
	107,
	108,
	109,
	110,
	111,
	112,
	113,
	114,
	115,
	116,
	117,
	118,
	119,
	120,
	121,
	122,
	123,
	124,
	125,
	126,
	127,
	128,
	129,
	130,
	131,
	132,
	133,
	134,
	135,
	136,
	137,
	138,
	139,
	140,
	141,
	142,
	143,
	144,
	145,
	146,
	147,
	148,
	149,
	150,
	151,
	152,
	153,
	154,
	155,
	156,
	157,
	158,
	159,
	160,
	161,
	162,
	163,
	164,
	165,
	166,
	167,
	168,
	169,
	170,
	171,
	172,
	173,
	174,
	175,
	176,
	177,
	178,
	179,
	180,
	181,
	182,
	183,
	184,
	185,
	186,
	187,
	188,
	189,
	190,
	191,
	192,
	193,
	194,
	195,
	196,
	197,
	198,
	199,
	200,
	201,
	202,
	203,
	204,
	205,
	206,
	207,
	208,
	209,
	210,
	211,
	212,
	213,
	214,
	215,
	249,
	250,
	251,
	252,
	253,
	254,
	255,
	256,
	257,
	258,
	259,
	260,
	261,
	262,
	263,
	264,
	265,
	266,
	267,
	268,
	269,
	270,
	271,
	272,
	273,
	274,
	275,
	276,
	277,
	278,
	279,
	280,
	281,
	282,
	283,
	284,
	285,
	286,
	287,
	288,
	289,
	290,
	291,
	292,
	293,
	303,
	304,
	305,
	306,
	307,
	308,
	309,
	310,
	311,
	312,
	313,
	314,
	315,
	316,
	317,
	318,
	319,
	320,
	321,
	322,
	323,
	324,
	325,
	326,
	353,
	360,
	361,
	362,
	363,
	365,
	366,
	367,
	368,
	369,
	370,
	371,
	372,
	373,
	374,
	375,
	376,
	377,
	378,
	379,
	380,
	381,
	382,
	383,
	384,
	385,
	386,
	387,
	388,
	389,
	390,
	391,
	392,
	393,
	394,
	395,
	396,
	397,
	431,
	432,
	433,
	434,
	444,
	460,
	461,
	462,
	463,
	464,
	465,
	466,
	467,
	468,
	469,
	470,
	471,
	472,
	473,
	474,
	479,
	480,
	481,
	482,
	484,
	485,
	487,
	488,
	489,
	492,
	493,
	494,
	496,
	497,
	498,
	499,
	500,
	501,
	502,
	503,
	504,
	505,
	506,
	507,
	512,
	513,
	514,
	515,
	516,
	517,
	518,
	519,
	520,
	521,
	522,
	523,
	524,
	525,
	526,
	527,
	528,
	529,
	530,
	531,
	532,
	533,
	534,
	535,
	536,
	537,
	538,
	539,
	540,
	541,
	542,
	543,
	544,
	545,
	546,
	547,
	548,
	549,
	550,
	551,
	552,
	553,
	554,
	555,
	556,
	557,
	558,
	559,
	560,
	561,
	562,
	563,
	564,
	565,
	566,
	567,
	568,
	569,
	570,
	571,
	572,
	573,
	574,
	575,
	576,
	577,
	578,
	579,
	580,
	581,
	582,
	583,
	584,
	585,
	586,
	587,
	588,
	589,
	590,
	591,
	592,
	593,
	594,
	595,
	596,
	597,
	598,
	599,
	600,
	601,
	602,
	603,
	604,
	605,
	606,
	607,
	608,
	609,
	610,
	611,
	612,
	613,
	614,
	615,
	616,
	617,
	618,
	619,
	620,
	621,
	622,
	623,
	624,
	625,
	626,
	627,
	628,
	629,
	630,
	631,
	632,
	633,
	634,
	635,
	636,
	637,
	638,
	639,
	640,
	641,
	642,
	643,
	644,
	645,
	646,
	647,
	648,
	649,
	650,
	651,
	652,
	653,
	654,
	655,
	656,
	657,
	658,
	659,
	660,
	661,
	662,
	663,
	664,
	665,
	666,
	667,
	668,
	669,
	670,
	671,
	672,
	673,
	674,
	675,
	676,
	677,
	678,
	679,
	680,
	681,
	682,
	683,
	684,
	685,
	686,
	687,
	688,
	689,
	690,
	691,
	692,
	693,
	694,
	695,
	696,
	697,
	698,
	699,
	700,
	701,
	702,
	703,
	704,
	705,
	706,
	707,
	708,
	709,
	710,
	711,
	712,
	713,
	714,
	715,
	716,
	717,
	718,
	719,
	720,
	721,
	722,
	723,
	724,
	725,
	726,
	727,
	728,
	729,
	730,
	731,
	732,
	733,
	734,
	735,
	736,
	737,
	738,
	739,
	740,
	741,
	742,
	743,
	744,
	745,
	746,
	747,
	748,
	749,
	750,
	760,
	761,
	762,
	768,
	769,
	770,
	771,
	772,
	773,
	774,
	775,
	776,
	777,
	778,
	779,
	780,
	781,
	782,
	783,
	784,
	785,
	786,
	787,
	788,
	789,
	790,
	791,
	792,
	793,
	794,
	795,
	796,
	797,
	798,
	799,
	800,
	801,
	802,
	803,
	3584,
	3585
};

static const char32_t unicode_starting_pagetab[]={
	0,
	14,
	15,
	21,
	38,
	41,
	48,
	65,
	72,
	82,
	101,
	131,
	161,
	187,
	206,
	220,
	228,
	235,
	236,
	250,
	257,
	258,
	259,
	264,
	275,
	283,
	295,
	303,
	308,
	328,
	340,
	341,
	357,
	368,
	380,
	381,
	382,
	385,
	386,
	387,
	388,
	389,
	390,
	391,
	394,
	398,
	414,
	417,
	419,
	438,
	445,
	451,
	453,
	454,
	455,
	456,
	457,
	458,
	459,
	460,
	461,
	462,
	463,
	464,
	465,
	466,
	467,
	468,
	469,
	470,
	471,
	472,
	473,
	474,
	475,
	476,
	477,
	478,
	480,
	481,
	482,
	483,
	484,
	485,
	486,
	487,
	488,
	489,
	490,
	491,
	492,
	493,
	494,
	495,
	496,
	497,
	498,
	499,
	500,
	501,
	502,
	503,
	504,
	505,
	506,
	507,
	508,
	509,
	510,
	511,
	512,
	513,
	514,
	515,
	516,
	517,
	518,
	519,
	520,
	521,
	522,
	523,
	524,
	525,
	526,
	527,
	528,
	529,
	530,
	531,
	532,
	533,
	534,
	535,
	536,
	537,
	538,
	539,
	540,
	541,
	542,
	543,
	544,
	545,
	546,
	547,
	548,
	549,
	550,
	551,
	552,
	553,
	554,
	555,
	556,
	557,
	558,
	559,
	560,
	561,
	562,
	563,
	564,
	565,
	566,
	569,
	570,
	573,
	581,
	587,
	598,
	606,
	620,
	621,
	622,
	623,
	624,
	625,
	626,
	627,
	628,
	629,
	630,
	631,
	632,
	633,
	634,
	635,
	636,
	637,
	638,
	639,
	640,
	641,
	642,
	643,
	644,
	645,
	646,
	647,
	648,
	649,
	650,
	651,
	652,
	653,
	654,
	655,
	656,
	657,
	658,
	659,
	660,
	661,
	662,
	663,
	666,
	667,
	669,
	679,
	680,
	686,
	696,
	713,
	720,
	728,
	732,
	740,
	746,
	758,
	759,
	765,
	779,
	787,
	799,
	808,
	812,
	817,
	823,
	828,
	835,
	840,
	849,
	876,
	880,
	882,
	888,
	891,
	894,
	905,
	909,
	912,
	919,
	932,
	933,
	939,
	940,
	941,
	942,
	943,
	946,
	947,
	948,
	949,
	950,
	951,
	952,
	954,
	955,
	956,
	957,
	958,
	959,
	960,
	961,
	962,
	963,
	964,
	965,
	966,
	967,
	968,
	969,
	970,
	971,
	972,
	973,
	974,
	975,
	983,
	988,
	989,
	990,
	998,
	999,
	1000,
	1001,
	1002,
	1003,
	1004,
	1005,
	1006,
	1007,
	1008,
	1009,
	1010,
	1011,
	1012,
	1013,
	1014,
	1015,
	1016,
	1017,
	1018,
	1019,
	1020,
	1021,
	1022,
	1023,
	1024,
	1025,
	1026,
	1028,
	1029,
	1032,
	1034,
	1041,
	1042,
	1048,
	1049,
	1050,
	1051,
	1054,
	1055,
	1065,
	1068,
	1070,
	1080,
	1090,
	1092,
	1094,
	1095,
	1096,
	1099,
	1101,
	1108,
	1112,
	1115,
	1116,
	1118,
	1122,
	1124,
	1127,
	1128,
	1129,
	1163,
	1169,
	1171,
	1177,
	1178,
	1179,
	1180,
	1183,
	1187,
	1194,
	1195,
	1203,
	1205,
	1206,
	1207,
	1208,
	1209,
	1210,
	1211,
	1212,
	1213,
	1214,
	1215,
	1216,
	1217,
	1218,
	1219,
	1220,
	1221,
	1222,
	1223,
	1224,
	1225,
	1226,
	1227,
	1228,
	1229,
	1230,
	1231,
	1232,
	1233,
	1234,
	1235,
	1236,
	1237,
	1238,
	1239,
	1240,
	1241,
	1242,
	1243,
	1244,
	1245,
	1246,
	1247,
	1248,
	1249,
	1250,
	1251,
	1252,
	1253,
	1254,
	1255,
	1256,
	1257,
	1258,
	1259,
	1260,
	1261,
	1262,
	1263,
	1264,
	1265,
	1266,
	1267,
	1268,
	1269,
	1270,
	1271,
	1272,
	1273,
	1274,
	1275,
	1276,
	1277,
	1278,
	1279,
	1280,
	1281,
	1282,
	1283,
	1284,
	1285,
	1286,
	1287,
	1288,
	1289,
	1290,
	1291,
	1292,
	1293,
	1294,
	1295,
	1296,
	1297,
	1298,
	1299,
	1300,
	1301,
	1302,
	1303,
	1304,
	1305,
	1306,
	1307,
	1308,
	1309,
	1310,
	1311,
	1312,
	1313,
	1314,
	1315,
	1316,
	1317,
	1318,
	1319,
	1320,
	1321,
	1322,
	1323,
	1324,
	1325,
	1326,
	1327,
	1328,
	1329,
	1330,
	1331,
	1332,
	1333,
	1334,
	1335,
	1336,
	1337,
	1338,
	1339,
	1340,
	1341,
	1342,
	1343,
	1344,
	1345,
	1346,
	1347,
	1348,
	1349,
	1350,
	1351,
	1352,
	1353,
	1354,
	1355,
	1356,
	1357,
	1358,
	1359,
	1360,
	1361,
	1362,
	1363,
	1364,
	1365,
	1366,
	1367,
	1368,
	1369,
	1370,
	1371,
	1372,
	1373,
	1374,
	1375,
	1376,
	1377,
	1378,
	1379,
	1380,
	1381,
	1382,
	1383,
	1384,
	1385,
	1386,
	1387,
	1388,
	1390,
	1392,
	1393,
	1394,
	1395,
	1396,
	1397,
	1398,
	1399,
	1400,
	1401,
	1402,
	1403,
	1404,
	1405,
	1406,
	1407,
	1408,
	1409,
	1410,
	1411,
	1412,
	1413,
	1415,
	1416,
	1417,
	1418,
	1419,
	1420,
	1421,
	1422,
	1423,
	1424,
	1425,
	1426,
	1427,
	1428,
	1429,
	1430,
	1431,
	1432,
	1433,
	1434,
	1435,
	1436,
	1437,
	1438,
	1439,
	1440,
	1441,
	1442,
	1443,
	1445,
	1446,
	1447,
	1448,
	1449,
	1450,
	1451,
	1452,
	1453,
	1454,
	1455,
	1456,
	1457,
	1458,
	1459,
	1460,
	1461,
	1462,
	1463,
	1464,
	1465,
	1466,
	1467,
	1468,
	1469,
	1470,
	1472,
	1473,
	1474,
	1475,
	1476,
	1477,
	1478,
	1479,
	1480,
	1481,
	1482,
	1483,
	1484,
	1485,
	1486,
	1487,
	1488,
	1490
};

